@@ -708,8 +708,7 @@ std::vector<std::pair<double, unsigned int>> FPBReader::getTanimotoNeighbors(
   PRECONDITION(df_init, "not initialized");
   std::vector<std::pair<double, unsigned int>> res;
   detail::tanimotoNeighbors(dp_impl, bv, threshold, res, usePopcountScreen);
-  std::sort(res.begin(), res.end(),
-            Rankers::pairGreater<double, unsigned int>());
+  std::sort(res.begin(), res.end(), Rankers::pairGreater);
   return res;
 }
 
@@ -743,8 +742,7 @@ std::vector<std::pair<double, unsigned int>> FPBReader::getTverskyNeighbors(
   std::vector<std::pair<double, unsigned int>> res;
   detail::tverskyNeighbors(dp_impl, bv, ca, cb, threshold, res,
                            usePopcountScreen);
-  std::sort(res.begin(), res.end(),
-            Rankers::pairGreater<double, unsigned int>());
+  std::sort(res.begin(), res.end(), Rankers::pairGreater);
   return res;
 }
 
