@@ -115,36 +115,36 @@ class TestCase(unittest.TestCase):
       bulk = getattr(DataStructs, f'Bulk{metric}Similarity')
       single = getattr(DataStructs, f'{metric}Similarity')
     sims = bulk(bvs[0], bvs)
-    for i in range(len(bvs)):
-      sim = single(bvs[0], bvs[i])
+    for i, bbvs in enumerate(bvs):
+      sim = single(bvs[0], bbvs)
       self.assertEqual(sim, sims[i])
-      self.assertEqual(sim, single(bvs[0], bvs[i].ToBinary()))
+      self.assertEqual(sim, single(bvs[0], bbvs.ToBinary()))
     dists = bulk(bvs[0], bvs, returnDistance=True)
-    for i in range(len(bvs)):
-      dist = single(bvs[0], bvs[i], returnDistance=True)
+    for i, bbvs in enumerate(bvs):
+      dist = single(bvs[0], bbvs, returnDistance=True)
       self.assertEqual(dist, dists[i])
-      self.assertEqual(dist, single(bvs[0], bvs[i].ToBinary(), returnDistance=True))
+      self.assertEqual(dist, single(bvs[0], bbvs.ToBinary(), returnDistance=True))
 
     sims = DataStructs.BulkTverskySimilarity(bvs[0], bvs, 1, 1)
-    for i in range(len(bvs)):
-      sim = DataStructs.TverskySimilarity(bvs[0], bvs[i], 1, 1)
+    for i, bbvs in enumerate(bvs):
+      sim = DataStructs.TverskySimilarity(bvs[0], bbvs, 1, 1)
       self.assertEqual(sim, sims[i])
-      sim = DataStructs.TanimotoSimilarity(bvs[0], bvs[i])
+      sim = DataStructs.TanimotoSimilarity(bvs[0], bbvs)
       self.assertEqual(sim, sims[i])
 
     sims = DataStructs.BulkTverskySimilarity(bvs[0], bvs, 1, 1, returnDistance=True)
-    for i in range(len(bvs)):
-      sim = DataStructs.TverskySimilarity(bvs[0], bvs[i], 1, 1, returnDistance=True)
+    for i, bbvs in enumerate(bvs):
+      sim = DataStructs.TverskySimilarity(bvs[0], bbvs, 1, 1, returnDistance=True)
       self.assertEqual(sim, sims[i])
-      sim = DataStructs.TanimotoSimilarity(bvs[0], bvs[i], returnDistance=True)
+      sim = DataStructs.TanimotoSimilarity(bvs[0], bbvs, returnDistance=True)
       self.assertEqual(sim, sims[i])
 
   def test6BulkOps(self):
     nbits = 10000
     bvs = []
-    for bvi in range(10):
+    for _ in range(10):
       bv = DataStructs.ExplicitBitVect(nbits)
-      for j in range(nbits):
+      for _ in range(nbits):
         x = random.randrange(0, nbits)
         bv.SetBit(x)
       bvs.append(bv)
@@ -153,9 +153,9 @@ class TestCase(unittest.TestCase):
   def test10BulkOps2(self):
     nbits = 10000
     bvs = []
-    for bvi in range(10):
+    for _ in range(10):
       bv = DataStructs.ExplicitBitVect(nbits)
-      for j in range(nbits):
+      for _ in range(nbits):
         x = random.randrange(0, nbits)
         bv.SetBit(x)
       bvs.append(bv)
@@ -167,7 +167,7 @@ class TestCase(unittest.TestCase):
     bvs = numpy.empty((10, ), DataStructs.ExplicitBitVect)
     for bvi in range(10):
       bv = DataStructs.ExplicitBitVect(nbits)
-      for j in range(nbits):
+      for _ in range(nbits):
         x = random.randrange(0, nbits)
         bv.SetBit(x)
       bvs[bvi] = bv
@@ -234,9 +234,9 @@ class TestCase(unittest.TestCase):
   def test11BulkNeighbors(self):
     nbits = 2048
     bvs = []
-    for bvi in range(1000):
+    for _ in range(1000):
       bv = DataStructs.ExplicitBitVect(nbits)
-      for j in range(nbits):
+      for _ in range(nbits):
         x = random.randrange(0, nbits)
         bv.SetBit(x)
       bvs.append(bv)
@@ -268,7 +268,7 @@ class TestCase(unittest.TestCase):
       self.assertEqual(l, l2)
       self.assertEqual(l, l3)
 
-      for j in range(nbits):
+      for _ in range(nbits):
         x = random.randrange(0, nbits)
         l[x] = 1
         bv.SetBit(x)
@@ -282,7 +282,7 @@ class TestCase(unittest.TestCase):
     nbits = 2048
     for cls in [DataStructs.ExplicitBitVect, DataStructs.SparseBitVect]:
       bv = cls(nbits)
-      for j in range(nbits):
+      for _ in range(nbits):
         x = random.randrange(0, nbits)
         bv.SetBit(x)
 
@@ -295,7 +295,7 @@ class TestCase(unittest.TestCase):
     for cls in [DataStructs.ExplicitBitVect, DataStructs.SparseBitVect]:
       bv = cls(nbits)
       bv2 = cls(nbits)
-      for j in range(nbits):
+      for _ in range(nbits):
         x = random.randrange(0, nbits)
         bv.SetBit(x)
         bv2[-(nbits - x)] = 1
