@@ -65,44 +65,56 @@ or by indexing (i.e. bv[i] = 1 or if bv[i]).\n\
 struct EBV_wrapper {
   static void wrap() {
     python::class_<ExplicitBitVect, boost::shared_ptr<ExplicitBitVect>>(
-        "ExplicitBitVect", ebvClassDoc.c_str(), python::init<unsigned int>())
-        .def(python::init<std::string>())
-        .def(python::init<unsigned int, bool>(python::args("size", "bitsSet")))
+        "ExplicitBitVect", ebvClassDoc.c_str(),
+        python::init<unsigned int>(python::args("self", "size")))
+        .def(python::init<std::string>(python::args("self", "pkl")))
+        .def(python::init<unsigned int, bool>(
+            python::args("self", "size", "bitsSet")))
         .def("SetBit", (bool(EBV::*)(unsigned int)) & EBV::setBit,
+             python::args("self", "which"),
              "Turns on a particular bit.  Returns the original state of the "
              "bit.\n")
         .def("SetBitsFromList",
              (void (*)(EBV *, python::object))SetBitsFromList,
+             python::args("self", "onBitList"),
              "Turns on a set of bits.  The argument should be a tuple or list "
              "of bit ids.\n")
         .def("UnSetBit", (bool(EBV::*)(unsigned int)) & EBV::unsetBit,
+             python::args("self", "which"),
              "Turns off a particular bit.  Returns the original state of the "
              "bit.\n")
         .def("UnSetBitsFromList",
              (void (*)(EBV *, python::object))UnSetBitsFromList,
+             python::args("self", "offBitList"),
              "Turns off a set of bits.  The argument should be a tuple or list "
              "of bit ids.\n")
         .def("GetBit", (bool(EBV::*)(unsigned int) const) & EBV::getBit,
-             "Returns the value of a bit.\n")
-        .def("GetNumBits", &EBV::getNumBits,
+             python::args("self", "which"), "Returns the value of a bit.\n")
+        .def("GetNumBits", &EBV::getNumBits, python::args("self"),
              "Returns the number of bits in the vector (the vector's size).\n")
-        .def("__len__", &EBV::getNumBits)
-        .def("GetNumOnBits", &EBV::getNumOnBits,
+        .def("__len__", &EBV::getNumBits, python::args("self"))
+        .def("GetNumOnBits", &EBV::getNumOnBits, python::args("self"),
              "Returns the number of on bits.\n")
-        .def("GetNumOffBits", &EBV::getNumOffBits,
+        .def("GetNumOffBits", &EBV::getNumOffBits, python::args("self"),
              "Returns the number of off bits.\n")
-        .def("__getitem__", (int (*)(const EBV &, int))get_VectItem)
-        .def("__setitem__", (int (*)(EBV &, int, int))set_VectItem)
+        .def("__getitem__", (int (*)(const EBV &, int))get_VectItem,
+             python::args("self", "which"))
+        .def("__setitem__", (int (*)(EBV &, int, int))set_VectItem,
+             python::args("self", "which", "val"))
         .def("GetOnBits", (IntVect(*)(const EBV &))GetOnBits,
+             python::args("self"),
              "Returns a tuple containing IDs of the on bits.\n")
         .def("ToBinary", (python::object(*)(const EBV &))BVToBinary,
+             python::args("self"),
              "Returns an internal binary representation of the vector.\n")
         .def("FromBase64", (void (*)(EBV &, const std::string &))InitFromBase64,
+             python::args("self", "inD"),
              "Initializes the vector from a base64 encoded binary string.\n")
-        .def("ToBase64", (std::string(*)(EBV &))ToBase64,
+        .def("ToBase64", (std::string(*)(EBV &))ToBase64, python::args("self"),
              "Converts the vector to a base64 string (the base64 encoded "
              "version of the results of ToString()).\n")
         .def("ToList", (python::list(*)(const EBV &))ExplicitToList,
+             python::args("self"),
              "Return the Bitvector as a python list (faster than list(vect))")
         .def(python::self & python::self)
         .def(python::self | python::self)
