@@ -19,7 +19,7 @@
 #include <sstream>
 #include <fstream>
 #include <ios>
-#include <stdlib.h>
+#include <cstdlib>
 
 using namespace RDGeom;
 using namespace RDKit;
