@@ -270,7 +270,7 @@ std::string Atom::getSymbol() const {
 }
 
 unsigned int Atom::getDegree() const {
-  return getOwningMol().getAtomDegree(this);
+  return dp_mol ? getOwningMol().getAtomDegree(this) : 0;
 }
 
 unsigned int Atom::getTotalDegree() const {
@@ -284,12 +284,11 @@ unsigned int Atom::getTotalDegree() const {
 //
 unsigned int Atom::getTotalNumHs(bool includeNeighbors) const {
   int res = getNumExplicitHs() + getNumImplicitHs();
-  if (includeNeighbors) {
-    for (auto nbr : getOwningMol().atomNeighbors(this)) {
-      if (nbr->getAtomicNum() == 1) {
-        ++res;
-      }
-    }
+  if (includeNeighbors && dp_mol) {
+    auto nbrs = dp_mol->atomNeighbors(this);
+    res += std::count_if(nbrs.begin(), nbrs.end(), [](const auto nbr) {
+      return (nbr->getAtomicNum() == 1);
+    });
   }
   return res;
 }
@@ -302,27 +301,37 @@ unsigned int Atom::getNumImplicitHs() const {
   PRECONDITION(d_implicitValence > -1,
                "getNumImplicitHs() called without preceding call to "
                "calcImplicitValence()");
-  return getImplicitValence();
+  return getValence(ValenceType::IMPLICIT);
 }
 
 int Atom::getExplicitValence() const {
-  PRECONDITION(
-      d_explicitValence > -1,
-      "getExplicitValence() called without call to calcExplicitValence()");
-  return d_explicitValence;
+  return getValence(ValenceType::EXPLICIT);
 }
 
 int Atom::getImplicitValence() const {
-  PRECONDITION(dp_mol,
-               "valence not defined for atoms not associated with molecules");
-  if (df_noImplicit) {
+  return getValence(ValenceType::IMPLICIT);
+}
+
+unsigned int Atom::getValence(ValenceType which) const {
+  if (!dp_mol) {
     return 0;
   }
-  return d_implicitValence;
+  PRECONDITION(
+      (which == ValenceType::IMPLICIT || d_explicitValence > -1),
+      "getValence(ValenceType::EXPLICIT) called without call to calcExplicitValence()");
+  PRECONDITION(
+      (which == ValenceType::EXPLICIT || df_noImplicit ||
+       d_implicitValence > -1),
+      "getValence(ValenceType::IMPLICIT) called without call to calcImplicitValence()");
+  if (which == ValenceType::EXPLICIT) {
+    return d_explicitValence;
+  } else {
+    return df_noImplicit ? 0 : d_implicitValence;
+  }
 }
 
 unsigned int Atom::getTotalValence() const {
-  return getExplicitValence() + getImplicitValence();
+  return getValence(ValenceType::EXPLICIT) + getValence(ValenceType::IMPLICIT);
 }
 
 namespace {
@@ -441,19 +450,20 @@ int calculateExplicitValence(const Atom &atom, bool strict, bool checkIt) {
   }
   return res;
 }
+}  // namespace
 
 // NOTE: this uses the explicitValence, so it will call
 // calculateExplicitValence if it is not set on the given atom
 int calculateImplicitValence(const Atom &atom, bool strict, bool checkIt) {
-  if (atom.getNoImplicit()) {
+  if (atom.df_noImplicit) {
     return 0;
   }
-  auto explicitValence = atom.getExplicitValence();
+  auto explicitValence = atom.d_explicitValence;
   if (explicitValence == -1) {
     explicitValence = calculateExplicitValence(atom, strict, checkIt);
   }
   // special cases
-  auto atomicNum = atom.getAtomicNum();
+  auto atomicNum = atom.d_atomicNum;
   if (atomicNum == 0) {
     return 0;
   }
@@ -463,8 +473,8 @@ int calculateImplicitValence(const Atom &atom, bool strict, bool checkIt) {
     }
   }
 
-  auto formalCharge = atom.getFormalCharge();
-  auto numRadicalElectrons = atom.getNumRadicalElectrons();
+  auto formalCharge = atom.d_formalCharge;
+  auto numRadicalElectrons = atom.d_numRadicalElectrons;
   if (explicitValence == 0 && numRadicalElectrons == 0 && atomicNum == 1) {
     if (formalCharge == 1 || formalCharge == -1) {
       return 0;
@@ -485,16 +495,14 @@ int calculateImplicitValence(const Atom &atom, bool strict, bool checkIt) {
       }
     }
   }
-
-  int explicitPlusRadV =
-      atom.getExplicitValence() + atom.getNumRadicalElectrons();
+  int explicitPlusRadV = atom.d_explicitValence + atom.d_numRadicalElectrons;
 
   const auto &ovalens =
-      PeriodicTable::getTable()->getValenceList(atom.getAtomicNum());
+      PeriodicTable::getTable()->getValenceList(atom.d_atomicNum);
   // if we start with an atom that doesn't have specified valences, we stick
   // with that. otherwise we will use the effective valence for the rest of
   // this.
-  unsigned int effectiveAtomicNum = atom.getAtomicNum();
+  unsigned int effectiveAtomicNum = atom.d_atomicNum;
   if (ovalens.size() > 1 || ovalens[0] != -1) {
     effectiveAtomicNum = getEffectiveAtomicNum(atom, checkIt);
   }
@@ -531,7 +539,7 @@ int calculateImplicitValence(const Atom &atom, bool strict, bool checkIt) {
   // isoelectronic to Cl/Ar or Br/Kr, which do not support hypervalent forms.
   if (canBeHypervalent(atom, effectiveAtomicNum)) {
     effectiveAtomicNum = atomicNum;
-    explicitPlusRadV -= atom.getFormalCharge();
+    explicitPlusRadV -= atom.d_formalCharge;
   }
   const auto &valens =
       PeriodicTable::getTable()->getValenceList(effectiveAtomicNum);
@@ -607,8 +615,6 @@ int calculateImplicitValence(const Atom &atom, bool strict, bool checkIt) {
   return res;
 }
 
-}  // unnamed namespace
-
 int Atom::calcExplicitValence(bool strict) {
   bool checkIt = false;
   d_explicitValence = calculateExplicitValence(*this, strict, checkIt);
@@ -628,7 +634,7 @@ void Atom::setMonomerInfo(AtomMonomerInfo *info) {
   delete dp_monomerInfo;
   dp_monomerInfo = info;
 }
-  
+
 void Atom::setIsotope(unsigned int what) { d_isotope = what; }
 
 double Atom::getMass() const {
@@ -924,7 +930,8 @@ unsigned int numPiElectrons(const Atom &atom) {
   if (atom.getIsAromatic()) {
     res = 1;
   } else if (atom.getHybridization() != Atom::SP3) {
-    auto val = static_cast<unsigned int>(atom.getExplicitValence());
+    auto val =
+        static_cast<unsigned int>(atom.getValence(Atom::ValenceType::EXPLICIT));
     unsigned int physical_bonds = atom.getNumExplicitHs();
     const auto &mol = atom.getOwningMol();
     for (const auto bond : mol.atomBonds(&atom)) {
@@ -938,7 +945,6 @@ unsigned int numPiElectrons(const Atom &atom) {
   }
   return res;
 }
-
 }  // namespace RDKit
 
 namespace {
@@ -990,7 +996,6 @@ constexpr const char *chiralityToString(RDKit::Atom::ChiralType type) {
   return "";
 }
 }  // namespace
-
 std::ostream &operator<<(std::ostream &target, const RDKit::Atom &at) {
   target << at.getIdx() << " " << at.getAtomicNum() << " " << at.getSymbol();
   target << " chg: " << at.getFormalCharge();
