@@ -534,20 +534,22 @@ BOOST_PYTHON_MODULE(rdChemReactions) {
       &rdChemicalReactionExceptionTranslator);
 
   python::enum_<RDKit::FingerprintType>("FingerprintType")
-      .value("AtomPairFP", RDKit::AtomPairFP)
-      .value("TopologicalTorsion", RDKit::TopologicalTorsion)
-      .value("MorganFP", RDKit::MorganFP)
-      .value("RDKitFP", RDKit::RDKitFP)
-      .value("PatternFP", RDKit::PatternFP);
+      .value("AtomPairFP", RDKit::FingerprintType::AtomPairFP)
+      .value("TopologicalTorsion", RDKit::FingerprintType::TopologicalTorsionFP)
+      .value("MorganFP", RDKit::FingerprintType::MorganFP)
+      .value("RDKitFP", RDKit::FingerprintType::RDKitFP)
+      .value("PatternFP", RDKit::FingerprintType::PatternFP);
   std::string docStringReactionFPParams =
       "A class for storing parameters to manipulate the calculation of "
       "fingerprints of chemical reactions.";
 
   python::class_<RDKit::ReactionFingerprintParams>(
       "ReactionFingerprintParams", docStringReactionFPParams.c_str(),
-      python::init<>("Constructor, takes no arguments"))
+      python::init<>(python::args("self"), "Constructor, takes no arguments"))
       .def(python::init<bool, double, unsigned int, int, unsigned int,
-                        RDKit::FingerprintType>())
+                        RDKit::FingerprintType>(
+          python::args("self", "includeAgents", "bitRatioAgents",
+                       "nonAgentWeight", "agentWeight", "fpSize", "fpType")))
       .def_readwrite("fpSize", &RDKit::ReactionFingerprintParams::fpSize)
       .def_readwrite("fpType", &RDKit::ReactionFingerprintParams::fpType)
       .def_readwrite("bitRatioAgents",
@@ -582,24 +584,28 @@ Sample Usage:
   python::class_<RDKit::ChemicalReaction,
                  std::shared_ptr<RDKit::ChemicalReaction>>(
       "ChemicalReaction", docString.c_str(),
-      python::init<>("Constructor, takes no arguments"))
-      .def(python::init<const std::string &>())
-      .def(python::init<const RDKit::ChemicalReaction &>())
+      python::init<>(python::args("self"), "Constructor, takes no arguments"))
+      .def(python::init<const std::string &>(python::args("self", "binStr")))
+      .def(python::init<const RDKit::ChemicalReaction &>(
+          python::args("self", "other")))
       .def("GetNumReactantTemplates",
            &RDKit::ChemicalReaction::getNumReactantTemplates,
+           python::args("self"),
            "returns the number of reactants this reaction expects")
       .def("GetNumProductTemplates",
            &RDKit::ChemicalReaction::getNumProductTemplates,
+           python::args("self"),
            "returns the number of products this reaction generates")
       .def("GetNumAgentTemplates",
-           &RDKit::ChemicalReaction::getNumAgentTemplates,
+           &RDKit::ChemicalReaction::getNumAgentTemplates, python::args("self"),
            "returns the number of agents this reaction expects")
       .def("AddReactantTemplate", &RDKit::ChemicalReaction::addReactantTemplate,
+           python::args("self", "mol"),
            "adds a reactant (a Molecule) to the reaction")
       .def("AddProductTemplate", &RDKit::ChemicalReaction::addProductTemplate,
-           "adds a product (a Molecule)")
+           python::args("self", "mol"), "adds a product (a Molecule)")
       .def("AddAgentTemplate", &RDKit::ChemicalReaction::addAgentTemplate,
-           "adds a agent (a Molecule)")
+           python::args("self", "mol"), "adds a agent (a Molecule)")
       .def("RemoveUnmappedReactantTemplates",
            RDKit::RemoveUnmappedReactantTemplates,
            (python::arg("self"), python::arg("thresholdUnmappedAtoms") = 0.2,
@@ -639,6 +645,7 @@ Sample Usage:
            " stop the reaction when maxProducts have been generated "
            "[default=1000]")
       .def("RunReactant", RDKit::RunReactant,
+           python::args("self", "reactant", "reactionIdx"),
            "apply the reaction to a single reactant")
       .def("RunReactantInPlace", RDKit::RunReactantInPlace,
            (python::arg("self"), python::arg("reactant"),
@@ -650,7 +657,7 @@ Sample Usage:
            (python::arg("self"), python::arg("silent") = false),
            "initializes the reaction so that it can be used")
       .def("IsInitialized", &RDKit::ChemicalReaction::isInitialized,
-           "checks if the reaction is ready for use")
+           python::args("self"), "checks if the reaction is ready for use")
       .def("Validate", &RDKit::ValidateReaction,
            (python::arg("self"), python::arg("silent") = false),
            "checks the reaction for potential problems, returns "
@@ -683,12 +690,15 @@ Sample Usage:
            (python::arg("self"), python::arg("propertyFlags")),
            "Returns a binary string representation of the reaction.")
       .def("IsMoleculeReactant", RDKit::IsMoleculeReactantOfReaction,
+           python::args("self", "mol"),
            "returns whether or not the molecule has a substructure match to "
            "one of the reactants.")
       .def("IsMoleculeProduct", RDKit::IsMoleculeProductOfReaction,
+           python::args("self", "mol"),
            "returns whether or not the molecule has a substructure match to "
            "one of the products.")
       .def("IsMoleculeAgent", RDKit::IsMoleculeAgentOfReaction,
+           python::args("self", "mol"),
            "returns whether or not the molecule has a substructure match to "
            "one of the agents.")
       .def("GetReactingAtoms", &RDKit::GetReactingAtoms,
@@ -704,17 +714,18 @@ Sample Usage:
 
       .def("GetReactants", &RDKit::ChemicalReaction::getReactants,
            python::return_value_policy<python::reference_existing_object>(),
-           "get the reactant templates")
+           python::args("self"), "get the reactant templates")
       .def("GetProducts", &RDKit::ChemicalReaction::getProducts,
            python::return_value_policy<python::reference_existing_object>(),
-           "get the product templates")
+           python::args("self"), "get the product templates")
       .def("GetAgents", &RDKit::ChemicalReaction::getAgents,
            python::return_value_policy<python::reference_existing_object>(),
-           "get the agent templates")
+           python::args("self"), "get the agent templates")
       .def("GetSubstructParams", RDKit::getParamsHelper,
            python::return_value_policy<
                python::reference_existing_object,
                python::with_custodian_and_ward_postcall<0, 1>>(),
+           python::args("self"),
            "get the parameter object controlling the substructure matching")
 
       // properties
@@ -771,11 +782,13 @@ Sample Usage:
            "computed.\n"
            "                Defaults to False.\n\n")
       .def("HasProp", RDKit::MolHasProp<RDKit::ChemicalReaction>,
+           python::args("self", "key"),
            "Queries a molecule to see if a particular property has been "
            "assigned.\n\n"
            "  ARGUMENTS:\n"
            "    - key: the name of the property to check for (a string).\n")
       .def("GetProp", RDKit::GetProp<RDKit::ChemicalReaction, std::string>,
+           python::args("self", "key"),
            "Returns the value of the property.\n\n"
            "  ARGUMENTS:\n"
            "    - key: the name of the property to return (a string).\n\n"
@@ -784,6 +797,7 @@ Sample Usage:
            "    - If the property has not been set, a KeyError exception "
            "will be raised.\n")
       .def("GetDoubleProp", RDKit::GetProp<RDKit::ChemicalReaction, double>,
+           python::args("self", "key"),
            "Returns the double value of the property if possible.\n\n"
            "  ARGUMENTS:\n"
            "    - key: the name of the property to return (a string).\n\n"
@@ -792,6 +806,7 @@ Sample Usage:
            "    - If the property has not been set, a KeyError exception "
            "will be raised.\n")
       .def("GetIntProp", RDKit::GetProp<RDKit::ChemicalReaction, int>,
+           python::args("self", "key"),
            "Returns the integer value of the property if possible.\n\n"
            "  ARGUMENTS:\n"
            "    - key: the name of the property to return (a string).\n\n"
@@ -801,6 +816,7 @@ Sample Usage:
            "will be raised.\n")
       .def("GetUnsignedProp",
            RDKit::GetProp<RDKit::ChemicalReaction, unsigned int>,
+           python::args("self", "key"),
            "Returns the unsigned int value of the property if possible.\n\n"
            "  ARGUMENTS:\n"
            "    - key: the name of the property to return (a string).\n\n"
@@ -809,6 +825,7 @@ Sample Usage:
            "    - If the property has not been set, a KeyError exception "
            "will be raised.\n")
       .def("GetBoolProp", RDKit::GetProp<RDKit::ChemicalReaction, bool>,
+           python::args("self", "key"),
            "Returns the Bool value of the property if possible.\n\n"
            "  ARGUMENTS:\n"
            "    - key: the name of the property to return (a string).\n\n"
@@ -817,12 +834,14 @@ Sample Usage:
            "    - If the property has not been set, a KeyError exception "
            "will be raised.\n")
       .def("ClearProp", RDKit::MolClearProp<RDKit::ChemicalReaction>,
+           python::args("self", "key"),
            "Removes a property from the reaction.\n\n"
            "  ARGUMENTS:\n"
            "    - key: the name of the property to clear (a string).\n")
 
       .def("ClearComputedProps",
            RDKit::MolClearComputedProps<RDKit::ChemicalReaction>,
+           python::args("self"),
            "Removes all computed properties from the reaction.\n\n")
 
       .def("GetPropNames", &RDKit::ChemicalReaction::getPropList,
@@ -865,12 +884,53 @@ Sample Usage:
 see the documentation for rdkit.Chem.MolFromSmiles for an explanation\n\
 of the replacements argument.",
       python::return_value_policy<python::manage_new_object>());
-  python::def("ReactionToSmarts", RDKit::ChemicalReactionToRxnSmarts,
+  python::def("ReactionToSmarts",
+              (std::string(*)(const RDKit::ChemicalReaction &))
+                  RDKit::ChemicalReactionToRxnSmarts,
               (python::arg("reaction")),
               "construct a reaction SMARTS string for a ChemicalReaction");
-  python::def("ReactionToSmiles", RDKit::ChemicalReactionToRxnSmiles,
+  python::def("ReactionToSmiles",
+              (std::string(*)(const RDKit::ChemicalReaction &,
+                              bool))RDKit::ChemicalReactionToRxnSmiles,
               (python::arg("reaction"), python::arg("canonical") = true),
               "construct a reaction SMILES string for a ChemicalReaction");
+  python::def("ReactionToSmarts",
+              (std::string(*)(const RDKit::ChemicalReaction &,
+                              const RDKit::SmilesWriteParams &))
+                  RDKit::ChemicalReactionToRxnSmarts,
+              (python::arg("reaction"), python::arg("params")),
+              "construct a reaction SMARTS string for a ChemicalReaction");
+  python::def("ReactionToSmiles",
+              (std::string(*)(const RDKit::ChemicalReaction &,
+                              const RDKit::SmilesWriteParams &))
+                  RDKit::ChemicalReactionToRxnSmiles,
+              (python::arg("reaction"), python::arg("params")),
+              "construct a reaction SMILES string for a ChemicalReaction");
+
+  python::def("ReactionToCXSmarts",
+              (std::string(*)(const RDKit::ChemicalReaction &))
+                  RDKit::ChemicalReactionToCXRxnSmarts,
+              (python::arg("reaction")),
+              "construct a reaction SMARTS string for a ChemicalReaction");
+  python::def("ReactionToCXSmiles",
+              (std::string(*)(const RDKit::ChemicalReaction &,
+                              bool))RDKit::ChemicalReactionToCXRxnSmiles,
+              (python::arg("reaction"), python::arg("canonical") = true),
+              "construct a reaction SMILES string for a ChemicalReaction");
+  python::def("ReactionToCXSmarts",
+              (std::string(*)(const RDKit::ChemicalReaction &,
+                              const RDKit::SmilesWriteParams &,
+                              std::uint32_t))
+                  RDKit::ChemicalReactionToCXRxnSmarts,
+              (python::arg("reaction"), python::arg("params"), python::arg("flags") = RDKit::SmilesWrite::CXSmilesFields::CX_ALL),
+              "construct a reaction CXSMARTS string for a ChemicalReaction");
+  python::def("ReactionToCXSmiles",
+              (std::string(*)(const RDKit::ChemicalReaction &,
+                              const RDKit::SmilesWriteParams &,
+                              std::uint32_t))
+                  RDKit::ChemicalReactionToCXRxnSmiles,
+              (python::arg("reaction"), python::arg("params"), python::arg("flags") = RDKit::SmilesWrite::CXSmilesFields::CX_ALL),
+              "construct a reaction CXSMILES string for a ChemicalReaction");
 
   python::def(
       "ReactionFromRxnFile", RDKit::RxnFileToChemicalReaction,
@@ -945,10 +1005,12 @@ of the replacements argument.",
 #ifdef RDK_USE_BOOST_IOSTREAMS
   python::def("ReactionFromPNGFile", RDKit::PNGFileToChemicalReaction,
               "construct a ChemicalReaction from metadata in a PNG file",
-              python::return_value_policy<python::manage_new_object>());
+              python::return_value_policy<python::manage_new_object>(),
+              python::args("fname"));
   python::def("ReactionFromPNGString", RDKit::PNGStringToChemicalReaction,
               "construct a ChemicalReaction from an string with PNG data",
-              python::return_value_policy<python::manage_new_object>());
+              python::return_value_policy<python::manage_new_object>(),
+              python::args("data"));
   python::def(
       "ReactionMetadataToPNGFile", RDKit::addReactionToPNGFileHelper,
       (python::arg("mol"), python::arg("filename"),
@@ -967,7 +1029,8 @@ of the replacements argument.",
   python::def("ReactionFromMolecule", RDKit::RxnMolToChemicalReaction,
               "construct a ChemicalReaction from an molecule if the RXN role "
               "property of the molecule is set",
-              python::return_value_policy<python::manage_new_object>());
+              python::return_value_policy<python::manage_new_object>(),
+              python::args("mol"));
   python::def(
       "ReactionToMolecule", RDKit::ChemicalReactionToRxnMol,
       (python::arg("reaction")),
@@ -994,7 +1057,7 @@ of the replacements argument.",
 )DOC";
   python::def(
       "Compute2DCoordsForReaction", RDKit::Compute2DCoordsForReaction,
-      (python::arg("reaction"), python::arg("spacing") = 2.0,
+      (python::arg("reaction"), python::arg("spacing") = 1.0,
        python::arg("updateProps") = true, python::arg("canonOrient") = true,
        python::arg("nFlipsPerSample") = 0, python::arg("nSample") = 0,
        python::arg("sampleSeed") = 0, python::arg("permuteDeg4Nodes") = false,
@@ -1027,6 +1090,7 @@ of the replacements argument.",
               "tests if a molecule can be classified as an agent depending on "
               "the ratio of mapped atoms and a give threshold");
   python::def("HasReactionAtomMapping", RDKit::hasReactionAtomMapping,
+              python::args("rxn"),
               "tests if a reaction obtains any atom mapping");
   python::def("HasReactionSubstructMatch", RDKit::hasReactionSubstructMatch,
               (python::arg("reaction"), python::arg("queryReaction"),
@@ -1232,5 +1296,13 @@ One unrecognized group type in a comma-separated list makes the whole thing fail
                python::arg("catchErrors") = false),
               docString.c_str());
 
+  docString =
+      R"DOC(Does the usual molecular sanitization on each reactant, agent, and product of the reaction)DOC";
+  python::def("SanitizeRxnAsMols", RDKit::RxnOps::sanitizeRxnAsMols,
+              (python::arg("rxn"),
+               python::arg("sanitizeOps") =
+                   rdcast<unsigned int>(RDKit::MolOps::SANITIZE_ALL)),
+              docString.c_str());
+
   wrap_enumeration();
 }
