@@ -608,4 +608,11 @@ TEST_CASE(
   REQUIRE(m2);
   CHECK(m2->getNumAtoms() == m->getNumAtoms());  // No atoms removed
   CHECK(m2->getRingInfo()->isSymmSssr());
-}
\ No newline at end of file
+}
+
+TEST_CASE(
+  "Github #8288: molzip add linker bond functionality (fixes memory issue)", "[feature,bug]") {
+  auto m = "[*:1][*:2].C[*:1].S[*:2]"_smiles;
+  auto res = molzip(*m);
+  CHECK(MolToSmiles(*res) == "CS");
+}
