@@ -352,12 +352,7 @@ struct State {
   void freeAtomList(AtomList *ptr) {
     while (ptr) {
       AtomList *next = ptr->next;
-#if 0
-      ptr->next = freeList;
-      freeList = ptr;
-#else
       free(ptr);
-#endif
       ptr = next;
     }
   }
@@ -886,4 +881,4 @@ DoubleCubicLatticeVolume::DoubleCubicLatticeVolume(const ROMol &mol,
 }
 
 }  // namespace Descriptors
-}  // namespace RDKit
\ No newline at end of file
+}  // namespace RDKit
