@@ -12,7 +12,7 @@
 #include <DistGeom/BoundsMatrix.h>
 #include <DistGeom/DistGeomUtils.h>
 #include <DistGeom/TriangleSmooth.h>
-#include <DistGeom/ChiralViolationContrib.h>
+#include <DistGeom/ChiralViolationContribs.h>
 #include "BoundsMatrixBuilder.h"
 #include <ForceField/ForceField.h>
 #include <GraphMol/ROMol.h>
@@ -559,7 +559,7 @@ bool checkChiralCenters(const RDGeom::PointPtrVect *positions,
                         const EmbedParameters &) {
   // check the chiral volume:
   for (const auto &chiralSet : *eargs.chiralCenters) {
-    double vol = DistGeom::ChiralViolationContrib::calcChiralVolume(
+    double vol = DistGeom::calcChiralVolume(
         chiralSet->d_idx1, chiralSet->d_idx2, chiralSet->d_idx3,
         chiralSet->d_idx4, *positions);
     double lb = chiralSet->getLowerVolumeBound();
