@@ -210,8 +210,7 @@ class TestCase(unittest.TestCase):
     ]
 
     nconfs = []
-    expected = [4, 5, 5, 4, 5, 4]
-    expected = [3, 3, 5, 4, 4, 4]
+    expected = [3, 2, 7, 6, 3, 3]
     for smi in smiles:
       mol = Chem.MolFromSmiles(smi)
       cids = rdDistGeom.EmbedMultipleConfs(mol, 50, maxAttempts=30, randomSeed=100,
@@ -229,7 +228,7 @@ class TestCase(unittest.TestCase):
     params.pruneRmsThresh = 1.5
     params.useSymmetryForPruning = False
     nconfs = []
-    expected = [4, 5, 5, 4, 5, 4]
+    expected = [4, 5, 5, 6, 7, 3]
     for smi in smiles:
       mol = Chem.MolFromSmiles(smi)
       cids = rdDistGeom.EmbedMultipleConfs(mol, 50, params)
@@ -588,8 +587,9 @@ class TestCase(unittest.TestCase):
 
       conf1 = m1.GetConformer()
       conf2 = m2.GetConformer()
-      self.assertTrue((conf2.GetAtomPosition(3) - conf2.GetAtomPosition(0)).Length() > (
-        conf1.GetAtomPosition(3) - conf1.GetAtomPosition(0)).Length())
+      self.assertTrue((conf2.GetAtomPosition(3) -
+                       conf2.GetAtomPosition(0)).Length() > (conf1.GetAtomPosition(3) -
+                                                             conf1.GetAtomPosition(0)).Length())
 
   def testScaleBoundsMatForce(self):
     """
@@ -649,7 +649,7 @@ class TestCase(unittest.TestCase):
     smiles_mol = Chem.MolFromSmiles(smiles)
     mol = Chem.AddHs(smiles_mol)
     params = AllChem.ETKDGv3()
-    params.seed = 42
+    params.randomSeed = 0
     AllChem.EmbedMolecule(mol, params)
     conf = mol.GetConformer(0)
     for torsion in get_atom_mapping(mol):
@@ -676,18 +676,60 @@ class TestCase(unittest.TestCase):
     self.assertEqual(list(ts[0]["signs"]), [1, 1, 1, 1, 1, 1])
     self.assertEqual(list(ts[0]["atomIndices"]), [0, 1, 2, 3])
 
+  def testTrackFailures(self):
+    params = AllChem.ETKDGv3()
+    params.trackFailures = True
+    params.maxIterations = 50
+    params.randomSeed = 42
+    mol = Chem.MolFromSmiles('C=CC1=C(N)Oc2cc1c(-c1cc(C(C)O)cc(=O)cc1C1NCC(=O)N1)c(OC)c2OC')
+    mol = Chem.AddHs(mol)
+    AllChem.EmbedMolecule(mol, params)
+    cnts = params.GetFailureCounts()
+    self.assertGreater(cnts[AllChem.EmbedFailureCauses.INITIAL_COORDS], 5)
+    self.assertGreater(cnts[AllChem.EmbedFailureCauses.ETK_MINIMIZATION], 10)
 
-def testTrackFailures(self):
-  params = AllChem.ETKDGv3()
-  params.trackFailures = True
-  params.maxIterations = 50
-  params.randomSeed = 42
-  mol = Chem.MolFromSmiles('C=CC1=C(N)Oc2cc1c(-c1cc(C(C)O)cc(=O)cc1C1NCC(=O)N1)c(OC)c2OC')
-  mol = Chem.AddHs(mol)
-  AllChem.EmbedMolecule(mol, params)
-  cnts = params.GetFailureCounts()
-  self.assertGreater(cnts[AllChem.EmbedFailureCauses.INITIAL_COORDS], 5)
-  self.assertGreater(cnts[AllChem.EmbedFailureCauses.ETK_MINIMIZATION], 10)
+  def testCoordMap(self):
+    mol = Chem.AddHs(Chem.MolFromSmiles("OCCC"))
+    ps = rdDistGeom.EmbedParameters()
+    coordMap = {0: geom.Point3D(0, 0, 0), \
+                1: geom.Point3D(0, 0, 1.5),
+                2: geom.Point3D(0, 1.5, 1.5)
+                }
+    ps.SetCoordMap(coordMap)
+    ps.randomSeed = 42
+    rdDistGeom.EmbedMolecule(mol, ps)
+
+    conf = mol.GetConformer()
+    v1 = conf.GetAtomPosition(0) - conf.GetAtomPosition(1)
+    v2 = conf.GetAtomPosition(2) - conf.GetAtomPosition(1)
+    angle = v1.AngleTo(v2)
+    self.assertAlmostEqual(angle, math.pi / 2.0, delta=0.15)
+
+    # make sure that we can call that a second time
+    coordMap = {0: geom.Point3D(0, 0, 0), \
+                1: geom.Point3D(1.5, 0, 0),
+                2: geom.Point3D(1.5, 1.5, 0)
+                }
+    ps.SetCoordMap(coordMap)
+    ps.randomSeed = 42
+    rdDistGeom.EmbedMolecule(mol, ps)
+
+    conf = mol.GetConformer()
+    v1 = conf.GetAtomPosition(0) - conf.GetAtomPosition(1)
+    v2 = conf.GetAtomPosition(2) - conf.GetAtomPosition(1)
+    angle = v1.AngleTo(v2)
+    self.assertAlmostEqual(angle, math.pi / 2.0, delta=0.15)
+
+  def testSymmetrizeTerminal(self):
+    mol = Chem.AddHs(Chem.MolFromSmiles("FCC(=O)O"))
+    ps = rdDistGeom.ETKDGv3()
+    ps.randomSeed = 0xc0ffee
+    ps.pruneRmsThresh = 0.5
+    cids = rdDistGeom.EmbedMultipleConfs(mol, 50, ps)
+    self.assertEqual(len(cids), 1)
+    ps.symmetrizeConjugatedTerminalGroupsForPruning = False
+    cids = rdDistGeom.EmbedMultipleConfs(mol, 50, ps)
+    self.assertGreater(len(cids), 1)
 
 
 if __name__ == '__main__':
