@@ -1604,6 +1604,68 @@ M  END)CTAB"_ctab;
   }
 }
 
+void testMolFileGithub8265() {
+  BOOST_LOG(rdInfoLog) << "-----------------------------------------\n";
+  BOOST_LOG(rdInfoLog) << "Running testMolFileGithub8265()\n";
+  auto m = "C"_smiles;
+  auto conf = new Conformer(1);
+  m->addConformer(conf);
+  
+  for( int i=0; i<2; ++i) {
+    RDGeom::Point3D pos{0., 0., 0.};
+   
+    // Make sure se switch to V3000 then coords are out of bounds
+    //  and that we stay with V2K otherwise.
+    {
+      pos[i] = 100000.;
+      conf->setAtomPos(0, pos);
+      auto mbV2K = MolToMolBlock(*m);
+      TEST_ASSERT(mbV2K.find("M  V30") != std::string::npos);
+      MolBlockToMol(mbV2K);
+      try {
+        MolToV2KMolBlock(*m);
+        TEST_ASSERT(0);
+      } catch(ValueErrorException &e) {
+        TEST_ASSERT(std::string("V2000 format does not support atom positions <= -10000 or >= 100000")
+                    == e.what());
+      }
+    }
+    
+    {
+      pos[i] = 99999.;
+      conf->setAtomPos(0, pos);
+      auto mbV2k = MolToMolBlock(*m);
+      TEST_ASSERT(mbV2k.find("M  V30") == std::string::npos);
+      MolBlockToMol(mbV2k);
+    }
+
+    {
+      pos[i] = -10000.;
+      conf->setAtomPos(0, pos);
+      auto mbV2k = MolToMolBlock(*m);
+      TEST_ASSERT(mbV2k.find("M  V30") != std::string::npos);
+      MolBlockToMol(mbV2k);
+      try {
+        MolToV2KMolBlock(*m);
+        TEST_ASSERT(0);
+      } catch(ValueErrorException &e) {
+        TEST_ASSERT(std::string("V2000 format does not support atom positions <= -10000 or >= 100000")
+                    == e.what());
+      }
+    }
+
+    {
+      pos[i] = -9999.;
+      conf->setAtomPos(0, pos);
+      auto mbV2k = MolToMolBlock(*m);
+      TEST_ASSERT(mbV2k.find("M  V30") == std::string::npos);
+      MolBlockToMol(mbV2k);
+    }
+  }
+  BOOST_LOG(rdInfoLog) << "Finished\n";
+  BOOST_LOG(rdInfoLog) << "-----------------------------------------\n\n";
+}
+
 int main() {
   RDLog::InitLogs();
 
@@ -1758,4 +1820,6 @@ int main() {
   BOOST_LOG(rdInfoLog) << "-----------------------------------------\n";
   testRGPMolFileWriterV2KV3K();
   BOOST_LOG(rdInfoLog) << "-----------------------------------------\n\n";
+  
+  testMolFileGithub8265();
 }
