@@ -89,8 +89,8 @@ bool isAtomPotentialTetrahedralCenter(const Atom *atom) {
         // sulfur or selenium with either a positive charge or a double
         // bond:
         if ((atom->getAtomicNum() == 16 || atom->getAtomicNum() == 34) &&
-            (atom->getExplicitValence() == 4 ||
-             (atom->getExplicitValence() == 3 &&
+            (atom->getValence(Atom::ValenceType::EXPLICIT) == 4 ||
+             (atom->getValence(Atom::ValenceType::EXPLICIT) == 3 &&
               atom->getFormalCharge() == 1))) {
           legalCenter = true;
         } else if (atom->getAtomicNum() == 7) {
