@@ -39,27 +39,6 @@
 
 namespace RDKit {
 namespace AtomPairs {
-unsigned int numPiElectrons(const Atom *atom) {
-  PRECONDITION(atom, "no atom");
-  unsigned int res = 0;
-  if (atom->getIsAromatic()) {
-    res = 1;
-  } else if (atom->getHybridization() != Atom::SP3) {
-    auto val = static_cast<unsigned int>(atom->getExplicitValence());
-    unsigned int physical_bonds = atom->getNumExplicitHs();
-    const auto &mol = atom->getOwningMol();
-    for (const auto &bndi :
-         boost::make_iterator_range(mol.getAtomBonds(atom))) {
-      if (mol[bndi]->getValenceContrib(atom) != 0.0) {
-        ++physical_bonds;
-      }
-    }
-    CHECK_INVARIANT(val >= physical_bonds,
-                    "explicit valence exceeds atom degree");
-    res = val - physical_bonds;
-  }
-  return res;
-}
 
 std::uint32_t getAtomCode(const Atom *atom, unsigned int branchSubtract,
                           bool includeChirality) {
@@ -72,7 +51,7 @@ std::uint32_t getAtomCode(const Atom *atom, unsigned int branchSubtract,
   }
 
   code = numBranches % maxNumBranches;
-  unsigned int nPi = numPiElectrons(atom) % maxNumPi;
+  unsigned int nPi = numPiElectrons(*atom) % maxNumPi;
   code |= nPi << numBranchBits;
 
   unsigned int typeIdx = 0;
@@ -205,7 +184,7 @@ $([N;H0&+0]([C;!$(C(=O))])([C;!$(C(=O))])[C;!$(C(=O))])]",  // Basic
 
 const RDKit::ROMol *ss_matcher::getMatcher() const { return m_matcher.get(); }
 
-ss_matcher::ss_matcher(){};
+ss_matcher::ss_matcher() {};
 ss_matcher::ss_matcher(const std::string &pattern) {
   RDKit::RWMol *p = RDKit::SmartsToMol(pattern);
   TEST_ASSERT(p);
