@@ -1,7 +1,5 @@
-//  Copyright (C) 2013-2018 Paolo Tosco
-//
-//  Copyright (C) 2004-2010 Greg Landrum and Rational Discovery LLC
-//
+//  Copyright (C) 2014-2025 Greg Landrum and other RDKit contributors
+
 //   @@ All Rights Reserved @@
 //  This file is part of the RDKit.
 //  The contents are covered by the terms of the BSD license
@@ -10,7 +8,6 @@
 //
 #include <iostream>
 #include <cmath>
-#include <cctype>
 
 #include <RDGeneral/Invariant.h>
 #include <GraphMol/RDKitBase.h>
@@ -53,6 +50,9 @@ void addBonds(const ROMol &mol, MMFFMolProperties *mmffMolProperties,
               << std::endl;
     }
   }
+
+  auto contrib = std::make_unique<BondStretchContrib>(field);
+  bool hasContrib = false;
   for (ROMol::ConstBondIterator bi = mol.beginBonds(); bi != mol.endBonds();
        ++bi) {
     unsigned int idx1 = (*bi)->getBeginAtomIdx();
@@ -61,9 +61,8 @@ void addBonds(const ROMol &mol, MMFFMolProperties *mmffMolProperties,
     MMFFBond mmffBondParams;
     if (mmffMolProperties->getMMFFBondStretchParams(mol, idx1, idx2, bondType,
                                                     mmffBondParams)) {
-      auto *contrib =
-          new BondStretchContrib(field, idx1, idx2, &mmffBondParams);
-      field->contribs().push_back(ForceFields::ContribPtr(contrib));
+      contrib->addTerm(idx1, idx2, &mmffBondParams);
+      hasContrib = true;
       if (mmffMolProperties->getMMFFVerbosity()) {
         unsigned int iAtomType = mmffMolProperties->getMMFFAtomType(idx1);
         unsigned int jAtomType = mmffMolProperties->getMMFFAtomType(idx2);
@@ -96,6 +95,9 @@ void addBonds(const ROMol &mol, MMFFMolProperties *mmffMolProperties,
             << std::fixed << std::setprecision(4) << totalBondStretchEnergy
             << std::endl;
   }
+  if (hasContrib) {
+    field->contribs().push_back(ForceFields::ContribPtr(contrib.release()));
+  }
 }
 
 unsigned int twoBitCellPos(unsigned int nAtoms, int i, int j) {
@@ -248,6 +250,8 @@ void addAngles(const ROMol &mol, MMFFMolProperties *mmffMolProperties,
     }
     points = field->positions();
   }
+  auto contrib = std::make_unique<AngleBendContrib>(field);
+  bool hasContrib = false;
   for (idx[1] = 0; idx[1] < nAtoms; ++idx[1]) {
     const Atom *jAtom = mol.getAtomWithIdx(idx[1]);
     if (jAtom->getDegree() == 1) {
@@ -270,11 +274,9 @@ void addAngles(const ROMol &mol, MMFFMolProperties *mmffMolProperties,
         MMFFAngle mmffAngleParams;
         if (mmffMolProperties->getMMFFAngleBendParams(
                 mol, idx[0], idx[1], idx[2], angleType, mmffAngleParams)) {
-          auto *contrib =
-              new AngleBendContrib(field, idx[0], idx[1], idx[2],
-                                   &mmffAngleParams, mmffPropParamsCentralAtom);
-          auto sptr = ForceFields::ContribPtr(contrib);
-          field->contribs().push_back(sptr);
+          hasContrib = true;
+          contrib->addTerm(idx[0], idx[1], idx[2],
+                           &mmffAngleParams, mmffPropParamsCentralAtom);
           if (mmffMolProperties->getMMFFVerbosity()) {
             unsigned int iAtomType = mmffMolProperties->getMMFFAtomType(idx[0]);
             unsigned int kAtomType = mmffMolProperties->getMMFFAtomType(idx[2]);
@@ -323,6 +325,9 @@ void addAngles(const ROMol &mol, MMFFMolProperties *mmffMolProperties,
             << std::fixed << std::setprecision(4) << totalAngleBendEnergy
             << std::endl;
   }
+  if (hasContrib) {
+    field->contribs().push_back(ForceFields::ContribPtr(contrib.release()));
+  }
 }
 
 // ------------------------------------------------------------------------
@@ -362,6 +367,10 @@ void addStretchBend(const ROMol &mol, MMFFMolProperties *mmffMolProperties,
     }
     points = field->positions();
   }
+
+  auto contrib = std::make_unique<StretchBendContrib>(field);
+  bool contribAdded = false;
+
   for (idx[1] = 0; idx[1] < nAtoms; ++idx[1]) {
     const Atom *jAtom = mol.getAtomWithIdx(idx[1]);
     if (jAtom->getDegree() == 1) {
@@ -393,10 +402,10 @@ void addStretchBend(const ROMol &mol, MMFFMolProperties *mmffMolProperties,
         if (mmffMolProperties->getMMFFStretchBendParams(
                 mol, idx[0], idx[1], idx[2], stretchBendType, mmffStbnParams,
                 mmffBondParams, mmffAngleParams)) {
-          auto *contrib = new StretchBendContrib(
-              field, idx[0], idx[1], idx[2], &mmffStbnParams, &mmffAngleParams,
-              &mmffBondParams[0], &mmffBondParams[1]);
-          field->contribs().push_back(ForceFields::ContribPtr(contrib));
+          contribAdded = true;
+          contrib->addTerm(idx[0], idx[1], idx[2], &mmffStbnParams,
+                           &mmffAngleParams, &mmffBondParams[0],
+                           &mmffBondParams[1]);
           if (mmffMolProperties->getMMFFVerbosity()) {
             unsigned int iAtomType = mmffMolProperties->getMMFFAtomType(idx[0]);
             unsigned int jAtomType = mmffMolProperties->getMMFFAtomType(idx[1]);
@@ -472,6 +481,9 @@ void addStretchBend(const ROMol &mol, MMFFMolProperties *mmffMolProperties,
             << std::fixed << std::setprecision(4) << totalStretchBendEnergy
             << std::endl;
   }
+  if (contribAdded) {
+    field->contribs().push_back(ForceFields::ContribPtr(contrib.release()));
+  }
 }
 
 void addOop(const ROMol &mol, MMFFMolProperties *mmffMolProperties,
@@ -505,6 +517,8 @@ void addOop(const ROMol &mol, MMFFMolProperties *mmffMolProperties,
     }
     points = field->positions();
   }
+  bool hasContrib = false;
+  auto contrib = std::make_unique<OopBendContrib>(field);
   for (idx[1] = 0; idx[1] < mol.getNumAtoms(); ++idx[1]) {
     atom[1] = mol.getAtomWithIdx(idx[1]);
     if (atom[1]->getDegree() != 3) {
@@ -549,9 +563,8 @@ void addOop(const ROMol &mol, MMFFMolProperties *mmffMolProperties,
           n[3] = 0;
           break;
       }
-      auto *contrib = new OopBendContrib(field, idx[n[0]], idx[n[1]], idx[n[2]],
-                                         idx[n[3]], &mmffOopParams);
-      field->contribs().push_back(ForceFields::ContribPtr(contrib));
+      contrib->addTerm(idx[n[0]], idx[n[1]], idx[n[2]], idx[n[3]], &mmffOopParams);
+      hasContrib = true;
       if (mmffMolProperties->getMMFFVerbosity()) {
         const RDGeom::Point3D p1((*(points[idx[n[0]]]))[0],
                                  (*(points[idx[n[0]]]))[1],
@@ -594,6 +607,9 @@ void addOop(const ROMol &mol, MMFFMolProperties *mmffMolProperties,
             << std::fixed << std::setprecision(4) << totalOopBendEnergy
             << std::endl;
   }
+  if (hasContrib) {
+    field->contribs().push_back(ForceFields::ContribPtr(contrib.release()));
+  }
 }
 
 // ------------------------------------------------------------------------
@@ -665,6 +681,9 @@ void addTorsions(const ROMol &mol, MMFFMolProperties *mmffMolProperties,
     delete query;
   }
 
+  auto contrib = std::make_unique<TorsionAngleContrib>(field);
+  bool contribAdded = false;
+
   for (unsigned int i = 0; i < nHits; ++i) {
     MatchVectType match = matchVect[i];
     TEST_ASSERT(match.size() == 2);
@@ -698,9 +717,8 @@ void addTorsions(const ROMol &mol, MMFFMolProperties *mmffMolProperties,
                 MMFFTor mmffTorParams;
                 if (mmffMolProperties->getMMFFTorsionParams(
                         mol, idx1, idx2, idx3, idx4, torType, mmffTorParams)) {
-                  auto *contrib = new TorsionAngleContrib(
-                      field, idx1, idx2, idx3, idx4, &mmffTorParams);
-                  field->contribs().push_back(ForceFields::ContribPtr(contrib));
+                  contrib->addTerm(idx1, idx2, idx3, idx4, &mmffTorParams);
+                  contribAdded = true;
                   if (mmffMolProperties->getMMFFVerbosity()) {
                     const Atom *iAtom = mol.getAtomWithIdx(idx1);
                     const Atom *lAtom = mol.getAtomWithIdx(idx4);
@@ -768,6 +786,9 @@ void addTorsions(const ROMol &mol, MMFFMolProperties *mmffMolProperties,
             << std::fixed << std::setprecision(4) << totalTorsionEnergy
             << std::endl;
   }
+  if (contribAdded) {
+    field->contribs().push_back(ForceFields::ContribPtr(contrib.release()));
+  }
 }
 
 // ------------------------------------------------------------------------
@@ -807,6 +828,8 @@ void addVdW(const ROMol &mol, int confId, MMFFMolProperties *mmffMolProperties,
     }
   }
   const Conformer &conf = mol.getConformer(confId);
+  auto contrib = std::make_unique<VdWContrib>(field);
+  bool hasContrib = false;
   for (unsigned int i = 0; i < nAtoms; ++i) {
     for (unsigned int j = i + 1; j < nAtoms; ++j) {
       if (ignoreInterfragInteractions && (fragMapping[i] != fragMapping[j])) {
@@ -820,8 +843,8 @@ void addVdW(const ROMol &mol, int confId, MMFFMolProperties *mmffMolProperties,
         }
         MMFFVdWRijstarEps mmffVdWConstants;
         if (mmffMolProperties->getMMFFVdWParams(i, j, mmffVdWConstants)) {
-          auto *contrib = new VdWContrib(field, i, j, &mmffVdWConstants);
-          field->contribs().push_back(ForceFields::ContribPtr(contrib));
+          contrib->addTerm(i, j, &mmffVdWConstants);
+          hasContrib = true;
           if (mmffMolProperties->getMMFFVerbosity()) {
             const Atom *iAtom = mol.getAtomWithIdx(i);
             const Atom *jAtom = mol.getAtomWithIdx(j);
@@ -853,6 +876,9 @@ void addVdW(const ROMol &mol, int confId, MMFFMolProperties *mmffMolProperties,
             << std::fixed << std::setprecision(4) << totalVdWEnergy
             << std::endl;
   }
+  if (hasContrib) {
+    field->contribs().push_back(ForceFields::ContribPtr(contrib.release()));
+  }
 }
 
 // ------------------------------------------------------------------------
@@ -890,6 +916,8 @@ void addEle(const ROMol &mol, int confId, MMFFMolProperties *mmffMolProperties,
   const Conformer &conf = mol.getConformer(confId);
   double dielConst = mmffMolProperties->getMMFFDielectricConstant();
   std::uint8_t dielModel = mmffMolProperties->getMMFFDielectricModel();
+  auto contrib = std::make_unique<EleContrib>(field);
+  bool hasContrib = false;
   for (unsigned int i = 0; i < nAtoms; ++i) {
     for (unsigned int j = i + 1; j < nAtoms; ++j) {
       if (ignoreInterfragInteractions && (fragMapping[i] != fragMapping[j])) {
@@ -910,9 +938,9 @@ void addEle(const ROMol &mol, int confId, MMFFMolProperties *mmffMolProperties,
         double chargeTerm = mmffMolProperties->getMMFFPartialCharge(i) *
                             mmffMolProperties->getMMFFPartialCharge(j) /
                             dielConst;
-        auto *contrib =
-            new EleContrib(field, i, j, chargeTerm, dielModel, is1_4);
-        field->contribs().push_back(ForceFields::ContribPtr(contrib));
+        contrib->addTerm(i, j, chargeTerm, dielModel, is1_4);
+        hasContrib = true;
+
         if (mmffMolProperties->getMMFFVerbosity()) {
           const unsigned int iAtomType = mmffMolProperties->getMMFFAtomType(i);
           const unsigned int jAtomType = mmffMolProperties->getMMFFAtomType(j);
@@ -942,6 +970,9 @@ void addEle(const ROMol &mol, int confId, MMFFMolProperties *mmffMolProperties,
             << std::fixed << std::setprecision(4) << totalEleEnergy
             << std::endl;
   }
+  if (hasContrib) {
+    field->contribs().push_back(ForceFields::ContribPtr(contrib.release()));
+  }
 }
 
 }  // end of namespace Tools
