@@ -10,10 +10,10 @@
 #include <iostream>
 #include <GraphMol/RDKitBase.h>
 #include <ForceField/UFF/Params.h>
+#include <ForceField/UFF/Utils.h>
 #include <ForceField/UFF/BondStretch.h>
 #include <ForceField/UFF/AngleBend.h>
 #include <ForceField/UFF/TorsionAngle.h>
-#include <ForceField/UFF/Inversion.h>
 #include <ForceField/UFF/Nonbonded.h>
 #include <RDGeneral/Invariant.h>
 #include <RDGeneral/RDLog.h>
