@@ -21,6 +21,7 @@
 #include <GraphMol/Substruct/SubstructMatch.h>
 #include <GraphMol/GenericGroups/GenericGroups.h>
 #include <GraphMol/FileParsers/FileParsers.h>
+#include <GraphMol/MarvinParse/MarvinParser.h>
 
 using namespace RDKit;
 
@@ -273,6 +274,48 @@ M  END
   return out.str();
 }
 
+std::string getMRVQuery(const std::string groupToTest) {
+  std::ostringstream out;
+
+  out << R"MRVQQQ(<cml xmlns="http://www.chemaxon.com" version="ChemAxon file format v20.20.0, generated by vunknown" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="http://www.chemaxon.com http://www.chemaxon.com/marvin/schema/mrvSchema_20_20_0.xsd">
+    <MDocument>
+        <MChemicalStruct>
+            <molecule molID="m1">
+                <atomArray>
+                    <atom id="a1" elementType="O" x2="-1.3336693410482567" y2="0.3850084702795158" lonePair="2"/>
+                    <atom id="a2" elementType="C" x2="0" y2="-0.3850084702795158"/>
+                    <atom id="a3" elementType="R" x2="1.3336693410482567" y2="0.3850084702795158" sgroupRef="sg1"/>
+                </atomArray>
+                <bondArray>
+                    <bond id="b1" atomRefs2="a1 a2" order="2"/>
+                    <bond id="b2" atomRefs2="a2 a3" order="1"/>
+                </bondArray>
+                <molecule molID="m2" id="sg1" role="SuperatomSgroup" title=")MRVQQQ"
+      << groupToTest << R"MRVQQQ(">
+                    <atomArray>
+                        <atom id="a4" elementType="*" x2="1.3336693410482567" y2="0.3850084702795158" sgroupAttachmentPoint="1"/>
+                    </atomArray>
+                    <AttachmentPointArray>
+                        <attachmentPoint atom="a4" order="1" bond="b2"/>
+                    </AttachmentPointArray>
+                </molecule>
+            </molecule>
+        </MChemicalStruct>
+        <MElectronContainer occupation="0 0" radical="0" id="o1">
+            <MElectron atomRefs="m1.a1" difLoc="0.0 0.0 0.0"/>
+            <MElectron atomRefs="m1.a1" difLoc="0.0 0.0 0.0"/>
+        </MElectronContainer>
+        <MElectronContainer occupation="0 0" radical="0" id="o2">
+            <MElectron atomRefs="m1.a1" difLoc="0.0 0.0 0.0"/>
+            <MElectron atomRefs="m1.a1" difLoc="0.0 0.0 0.0"/>
+        </MElectronContainer>
+    </MDocument>
+</cml>
+)MRVQQQ";
+
+  return out.str();
+}
+
 void runTest(RWMol *query,
              std::vector<std::pair<std::string, unsigned>> &tests) {
   GenericGroups::setGenericQueriesFromProperties(*query, true, true);
@@ -321,6 +364,13 @@ void runMolTest(const std::string groupToTest,
   runTest(query.get(), tests);
 }
 
+void runMRVTest(const std::string groupToTest,
+                std::vector<std::pair<std::string, unsigned>> &tests) {
+  std::string queryString = getMRVQuery(groupToTest);
+  auto query = std::unique_ptr<RWMol>(MrvBlockToMol(queryString, false, false));
+  runTest(query.get(), tests);
+}
+
 void runTest(const std::string groupToTest,
              std::vector<std::pair<std::string, unsigned>> &tests) {
   runCxsmilesTest(groupToTest, tests, false);
@@ -330,6 +380,7 @@ void runTest(const std::string groupToTest,
     runMolTest(groupToTest, tests, false);
   }
   runMolTest(groupToTest, tests, true);
+  runMRVTest(groupToTest, tests);
 }
 
 TEST_CASE("alkyl", "[substructure][generics]") {
