@@ -9,4 +9,4 @@
 //
 #include "GraphMol.h"
 
-namespace RDKit {}  // end o' namespace
+namespace RDKit {}  // namespace RDKit
