@@ -639,7 +639,7 @@ class MarvinCMLReader {
           unsigned int failedOp = 0;
           MolOps::sanitizeMol(*mol, failedOp, MolOps::SANITIZE_CLEANUP);
           MolOps::detectBondStereochemistry(*mol);
-          MolOps::removeHs(*mol, false, false);
+          MolOps::removeHs(*mol);
         } else {
           MolOps::sanitizeMol(*mol);
           MolOps::detectBondStereochemistry(*mol);
