@@ -103,6 +103,11 @@ struct ContourParams {
   double isovalScaleForQuantization =
       1e6;  // scaling factor used to convert isovalues to ints when forming the
             // continuous lines
+  bool useFillThreshold =
+      false;  // use a magnitude threshold to determine if a grid box is filled
+  double fillThreshold = 0.01;  // magnitude threshold for filling grid boxes
+  bool fillThresholdIsFraction = true;  // if true, the fill threshold is a
+                                        // fraction of the range of the data
 };
 
 //! Generates and draws contours for data on a grid
