@@ -12,6 +12,7 @@
 #ifndef RDKIT_DRAWTEXTFTQT_H
 #define RDKIT_DRAWTEXTFTQT_H
 
+#include <RDGeneral/export.h>
 #include <GraphMol/MolDraw2D/DrawTextFT.h>
 #include "DrawTextQt.h"
 
@@ -20,13 +21,21 @@ class QPainterPath;
 
 namespace RDKit {
 
+namespace MolDraw2D_detail {
 // ****************************************************************************
 
-class DrawTextFTQt : public DrawTextFT {
+class RDKIT_MOLDRAW2DQT_EXPORT DrawTextFTQt : public DrawTextFT {
  public:
   DrawTextFTQt(double max_fnt_sz, double min_fnt_sz,
                const std::string &font_file, QPainter *qp);
 
+  ~DrawTextFTQt();
+
+  DrawTextFTQt(const DrawTextFTQt &rhs) = delete;
+  DrawTextFTQt(DrawTextFTQt &&rhs) = delete;
+  DrawTextFTQt &operator=(const DrawTextFTQt &rhs) = delete;
+  DrawTextFTQt &operator=(DrawTextFTQt &&rhs) = delete;
+
   int MoveToFunctionImpl(const FT_Vector *to) override;
   int LineToFunctionImpl(const FT_Vector *to) override;
   int ConicToFunctionImpl(const FT_Vector *control,
@@ -35,15 +44,14 @@ class DrawTextFTQt : public DrawTextFT {
                           const FT_Vector *controlTwo,
                           const FT_Vector *to) override;
 
- protected:
   // adds x_trans_ and y_trans_ to coords returns x advance distance
-  virtual double extractOutline() override;
+  double extractOutline() override;
 
  private:
   QPainter *d_qp;
   std::unique_ptr<QPainterPath> dp_qpp;
 };
 
+}  // namespace MolDraw2D_detail
 }  // namespace RDKit
-
 #endif  // RDKIT_DRAWTEXTFTQT_H
