@@ -1021,7 +1021,7 @@ BOOST_PYTHON_MODULE(rdMolDraw2D) {
           "standardColoursForHighlightedAtoms",
           &RDKit::MolDrawOptions::standardColoursForHighlightedAtoms,
           "If true, highlighted hetero atoms are drawn in standard colours"
-              " rather than black.  Default=False")
+          " rather than black.  Default=False")
       .def("getVariableAttachmentColour", &RDKit::getVariableAttachmentColour,
            python::args("self"),
            "method for getting the colour of variable attachment points")
@@ -1330,6 +1330,17 @@ BOOST_PYTHON_MODULE(rdMolDraw2D) {
           "isovalScaleForQuantization",
           &RDKit::MolDraw2DUtils::ContourParams::isovalScaleForQuantization,
           "scaling factor used to convert isovalues to ints when forming the continuous lines")
+      .def_readwrite(
+          "useFillThreshold",
+          &RDKit::MolDraw2DUtils::ContourParams::useFillThreshold,
+          "use a magnitude threshold to determine if a grid point is filled")
+      .def_readwrite(
+          "fillThreshold", &RDKit::MolDraw2DUtils::ContourParams::fillThreshold,
+          "magnitude threshold to determine if a grid point is filled")
+      .def_readwrite(
+          "fillThresholdIsFraction",
+          &RDKit::MolDraw2DUtils::ContourParams::fillThresholdIsFraction,
+          "if true, fillThreshold is a fraction of the range of the data")
       .def("setContourColour", &RDKit::setContourColour,
            (python::arg("self"), python::arg("colour")))
       .def("setColourMap", &RDKit::setColoursHelper,
@@ -1463,9 +1474,10 @@ https://en.wikipedia.org/wiki/Wikipedia:Manual_of_Style/Chemistry/Structure_draw
               (python::arg("mol"), python::arg("confId") = -1),
               "Calculate the mean bond length for the molecule.");
   python::def("SetDarkMode",
-              (void (*)(RDKit::MolDrawOptions &))&RDKit::setDarkMode,
+              (void (*)(RDKit::MolDrawOptions &)) & RDKit::setDarkMode,
               python::args("d2d"), "set dark mode for a MolDrawOptions object");
-  python::def("SetDarkMode", (void (*)(RDKit::MolDraw2D &))&RDKit::setDarkMode,
+  python::def("SetDarkMode",
+              (void (*)(RDKit::MolDraw2D &)) & RDKit::setDarkMode,
               python::args("d2d"), "set dark mode for a MolDraw2D object");
   python::def("SetMonochromeMode", RDKit::setMonochromeMode_helper1,
               (python::arg("options"), python::arg("fgColour"),
