@@ -24,6 +24,15 @@ class ROMol;
 namespace MolStandardize {
 class TautomerTransform;
 
+using TautomerTransformDefs =
+    std::vector<std::tuple<std::string, std::string, std::string, std::string>>;
+
+namespace defaults {
+RDKIT_MOLSTANDARDIZE_EXPORT extern const TautomerTransformDefs
+    defaultTautomerTransforms;
+RDKIT_MOLSTANDARDIZE_EXPORT extern const TautomerTransformDefs
+    defaultTautomerTransformsv1;
+}  // namespace defaults
 class RDKIT_MOLSTANDARDIZE_EXPORT TautomerCatalogParams
     : public RDCatalog::CatalogParams {
  public:
@@ -33,9 +42,7 @@ class RDKIT_MOLSTANDARDIZE_EXPORT TautomerCatalogParams
   }
 
   TautomerCatalogParams(const std::string &tautomerFile);
-  TautomerCatalogParams(
-      const std::vector<std::tuple<std::string, std::string, std::string,
-                                   std::string>> &data);
+  TautomerCatalogParams(const TautomerTransformDefs &data);
   // copy constructor
   TautomerCatalogParams(const TautomerCatalogParams &other);
 
