@@ -29,6 +29,12 @@ ROMol *chooseHelper(MolStandardize::LargestFragmentChooser &self,
                     const ROMol &mol) {
   return self.choose(mol);
 }
+
+void chooseInPlaceHelper(MolStandardize::LargestFragmentChooser &self,
+                         ROMol &mol) {
+  self.chooseInPlace(static_cast<RWMol &>(mol));
+}
+
 MolStandardize::FragmentRemover *removerFromParams(const std::string &data,
                                                    bool leave_last,
                                                    bool skip_if_all_match) {
@@ -48,9 +54,9 @@ struct fragment_wrapper {
     std::string docString = "";
 
     python::class_<MolStandardize::FragmentRemover, boost::noncopyable>(
-        "FragmentRemover", python::init<>())
+        "FragmentRemover", python::init<>(python::args("self")))
         .def(python::init<std::string, bool, bool>(
-            (python::arg("fragmentFilename") = "",
+            (python::arg("self"), python::arg("fragmentFilename") = "",
              python::arg("leave_last") = true,
              python::arg("skip_if_all_match") = false)))
         .def("remove", &removeHelper, (python::arg("self"), python::arg("mol")),
@@ -68,11 +74,16 @@ struct fragment_wrapper {
 
     python::class_<MolStandardize::LargestFragmentChooser, boost::noncopyable>(
         "LargestFragmentChooser",
-        python::init<bool>(python::arg("preferOrganic") = false))
+        python::init<bool>(
+            (python::arg("self"), python::arg("preferOrganic") = false)))
         .def(python::init<const MolStandardize::CleanupParameters &>(
-            python::arg("params")))
+            (python::arg("self"), python::arg("params"))))
         .def("choose", &chooseHelper, (python::arg("self"), python::arg("mol")),
-             "", python::return_value_policy<python::manage_new_object>());
+             "", python::return_value_policy<python::manage_new_object>())
+        .def("chooseInPlace", &chooseInPlaceHelper,
+             (python::arg("self"), python::arg("mol")), "",
+             python::return_value_policy<python::manage_new_object>());
+    ;
   }
 };
 
