@@ -23,8 +23,10 @@
 #include <unordered_set>
 #include <vector>
 
+#include <RDGeneral/BoostStartInclude.h>
 #include <boost/dynamic_bitset.hpp>
 #include <boost/algorithm/string.hpp>
+#include <RDGeneral/BoostEndInclude.h>
 
 #include <GraphMol/ROMol.h>
 #include <GraphMol/MolOps.h>
@@ -329,19 +331,25 @@ void makeLineGraph(const ROMol &mol, std::vector<std::vector<int>> &adjMatrix) {
   }
 }
 
-// make sure that mol1_bond in mol1 and mol2_bond in mol2 are, if aromatic, in
-// at least one ring that is the same.
-bool checkAromaticRings(const ROMol &mol1,
+// make sure that mol1_bond in mol1 and mol2_bond in mol2 are, in at least one
+// ring that is the same. If aromaticRingsMatchOnly is true, then only aromatic
+// bonds are considered.
+bool checkRings(const ROMol &mol1,
                         std::vector<std::string> &mol1RingSmiles,
                         int mol1BondIdx, const ROMol &mol2,
                         std::vector<std::string> &mol2RingSmiles,
-                        int mol2BondIdx) {
+                        int mol2BondIdx,
+                        bool aromaticRingsMatchOnly) {
   auto mol1Bond = mol1.getBondWithIdx(mol1BondIdx);
   auto mol2Bond = mol2.getBondWithIdx(mol2BondIdx);
-  if (!mol1Bond->getIsAromatic() || !mol2Bond->getIsAromatic()) {
+  if (aromaticRingsMatchOnly && (!mol1Bond->getIsAromatic() || !mol2Bond->getIsAromatic())) {
     return true;
   }
 
+  if (mol1Bond->getBondType() != mol2Bond->getBondType()) {
+    return false;
+  }
+
   // If neither bond was in a ring, but they were marked aromatic, then
   // the two mols are fragments so it's ok to match these bonds.
   const auto &mol1BondRings = mol1.getRingInfo()->bondRings();
@@ -445,12 +453,16 @@ void buildPairs(const ROMol &mol1, const std::vector<unsigned int> &vtxLabels1,
   for (auto i = 0u; i < vtxLabels1.size(); ++i) {
     for (auto j = 0u; j < vtxLabels2.size(); ++j) {
       if (vtxLabels1[i] == vtxLabels2[j]) {
-        if (opts.completeAromaticRings &&
-            !checkAromaticRings(mol1, mol1RingSmiles, i, mol2, mol2RingSmiles,
-                                j)) {
+        // completeSmallestRings automatically implies completeAromaticRings and 
+        // ringMatchesRingsOnly
+        if (opts.completeSmallestRings &&
+            !checkRings(mol1, mol1RingSmiles, i, mol2, mol2RingSmiles, j, false)) {
+          continue;
+        } else if (opts.completeAromaticRings &&
+            !checkRings(mol1, mol1RingSmiles, i, mol2, mol2RingSmiles, j, true)) {
           continue;
         }
-        if (opts.ringMatchesRingOnly &&
+        if (!opts.completeSmallestRings && opts.ringMatchesRingOnly &&
             !checkRingMatchesRing(mol1, i, mol2, j)) {
           continue;
         }
