@@ -277,16 +277,18 @@ void test3() {
 
   delete mol;
   sln = "C[1:+]H5";
-  mol = RDKit::SLNToMol(sln);
+  bool sanitize = false;
+  mol = RDKit::SLNToMol(sln, sanitize);
   TEST_ASSERT(mol);
-  TEST_ASSERT(mol->getNumAtoms() == 1);
+  mol->debugMol(std::cerr);
+  TEST_ASSERT(mol->getNumAtoms() == 6);
   TEST_ASSERT(mol->getAtomWithIdx(0)->getFormalCharge() == 1);
 
   delete mol;
   sln = "C[1:+2]H6";
-  mol = RDKit::SLNToMol(sln);
+  mol = RDKit::SLNToMol(sln, sanitize);
   TEST_ASSERT(mol);
-  TEST_ASSERT(mol->getNumAtoms() == 1);
+  TEST_ASSERT(mol->getNumAtoms() == 7);
   TEST_ASSERT(mol->getAtomWithIdx(0)->getFormalCharge() == 2);
 
   delete mol;
@@ -320,7 +322,6 @@ void test3() {
   TEST_ASSERT(mol->getAtomWithIdx(0)->getNoImplicit());
   TEST_ASSERT(mol->getAtomWithIdx(0)->getNumRadicalElectrons() == 1);
 
-#if 1
   // FIX: this should be accepted
 
   delete mol;
@@ -328,7 +329,6 @@ void test3() {
   mol = RDKit::SLNToMol(sln);  //,true,1);
   TEST_ASSERT(mol);
   TEST_ASSERT(mol->getNumAtoms() == 2);
-#endif
 
   // but this should not be accepted:
   delete mol;
@@ -376,7 +376,6 @@ void test5() {
   BOOST_LOG(rdInfoLog) << "-------------------------------------" << std::endl;
   BOOST_LOG(rdInfoLog) << "Test5: basic queries " << std::endl;
 
-#if 1
   sln = "C[charge=+1]";
   patt = RDKit::SLNQueryToMol(sln);
   TEST_ASSERT(patt);
@@ -386,7 +385,9 @@ void test5() {
   TEST_ASSERT(patt->getAtomWithIdx(0)->getNumImplicitHs() == 0);
 
   smi = "C[CH2+](C)C";
-  mol = RDKit::SmilesToMol(smi);
+  bool sanitize = false;
+  bool debugParse = false;
+  mol = RDKit::SmilesToMol(smi, debugParse, sanitize);
   TEST_ASSERT(mol);
   TEST_ASSERT(RDKit::SubstructMatch(*mol, *patt, mV) == 1);
 
@@ -398,7 +399,7 @@ void test5() {
 
   delete mol;
   smi = "C[CH3+2](C)C";
-  mol = RDKit::SmilesToMol(smi);
+  mol = RDKit::SmilesToMol(smi, debugParse, sanitize);
   TEST_ASSERT(mol);
   TEST_ASSERT(!RDKit::SubstructMatch(*mol, *patt, mV));
 
@@ -456,12 +457,12 @@ void test5() {
   TEST_ASSERT(patt->getNumAtoms() == 1);
   delete mol;
   smi = "C[CH2+](C)[CH+2]";
-  mol = RDKit::SmilesToMol(smi);
+  mol = RDKit::SmilesToMol(smi, debugParse, sanitize);
   TEST_ASSERT(mol);
   TEST_ASSERT(RDKit::SubstructMatch(*mol, *patt, mV) == 2);
   delete mol;
   smi = "C[CH2+](C)[N+2]";
-  mol = RDKit::SmilesToMol(smi);
+  mol = RDKit::SmilesToMol(smi, debugParse, sanitize);
   TEST_ASSERT(mol);
   TEST_ASSERT(RDKit::SubstructMatch(*mol, *patt, mV) == 1);
   delete mol;
@@ -477,7 +478,7 @@ void test5() {
   TEST_ASSERT(patt->getNumAtoms() == 1);
   delete mol;
   smi = "C[CH2+](CC)[NH+]";
-  mol = RDKit::SmilesToMol(smi);
+  mol = RDKit::SmilesToMol(smi, debugParse, sanitize);
   TEST_ASSERT(mol);
   TEST_ASSERT(RDKit::SubstructMatch(*mol, *patt, mV) == 1);
   TEST_ASSERT(mV[0][0].second == 1);
@@ -489,7 +490,7 @@ void test5() {
   TEST_ASSERT(patt->getNumAtoms() == 1);
   delete mol;
   smi = "C[CH2+](CC)[NH+]";
-  mol = RDKit::SmilesToMol(smi);
+  mol = RDKit::SmilesToMol(smi, debugParse, sanitize);
   TEST_ASSERT(mol);
   TEST_ASSERT(RDKit::SubstructMatch(*mol, *patt, mV) == 1);
   TEST_ASSERT(mV[0][0].second == 1);
@@ -501,7 +502,7 @@ void test5() {
   TEST_ASSERT(patt->getNumAtoms() == 1);
   delete mol;
   smi = "C[CH2+](CC)[NH+]";
-  mol = RDKit::SmilesToMol(smi);
+  mol = RDKit::SmilesToMol(smi, debugParse, sanitize);
   TEST_ASSERT(mol);
   TEST_ASSERT(RDKit::SubstructMatch(*mol, *patt, mV) == 1);
   TEST_ASSERT(mV[0][0].second == 4);
@@ -546,7 +547,6 @@ void test5() {
   TEST_ASSERT(patt->getNumAtoms() == 2);
   TEST_ASSERT(RDKit::SubstructMatch(*mol, *patt, mV) == 4);
   delete patt;
-#endif
 
   delete mol;
   smi = "CO[2H]";
@@ -755,7 +755,9 @@ void test7() {
   TEST_ASSERT(patt->getNumAtoms() == 1);
 
   smi = "C[CH2+](C)C";
-  mol = RDKit::SmilesToMol(smi);
+  bool debugParse = false;
+  bool sanitize = false;
+  mol = RDKit::SmilesToMol(smi, debugParse, sanitize);
   TEST_ASSERT(mol);
   TEST_ASSERT(RDKit::SubstructMatch(*mol, *patt, mV) == 1);
 
@@ -767,7 +769,7 @@ void test7() {
 
   delete mol;
   smi = "C[CH2+](C)C";
-  mol = RDKit::SmilesToMol(smi);
+  mol = RDKit::SmilesToMol(smi, debugParse, sanitize);
   TEST_ASSERT(mol);
   TEST_ASSERT(RDKit::SubstructMatch(*mol, *patt, mV) == 3);
 
@@ -779,7 +781,7 @@ void test7() {
 
   delete mol;
   smi = "C[CH3+2](C)C";
-  mol = RDKit::SmilesToMol(smi);
+  mol = RDKit::SmilesToMol(smi, debugParse, sanitize);
   TEST_ASSERT(mol);
   TEST_ASSERT(RDKit::SubstructMatch(*mol, *patt, mV) == 3);
 
@@ -790,7 +792,7 @@ void test7() {
 
   delete mol;
   smi = "C[CH2+](C)C";
-  mol = RDKit::SmilesToMol(smi);
+  mol = RDKit::SmilesToMol(smi, debugParse, sanitize);
   TEST_ASSERT(mol);
   TEST_ASSERT(RDKit::SubstructMatch(*mol, *patt, mV) == 4);
 
@@ -802,7 +804,7 @@ void test7() {
 
   delete mol;
   smi = "C[CH3+2](C)C";
-  mol = RDKit::SmilesToMol(smi);
+  mol = RDKit::SmilesToMol(smi, debugParse, sanitize);
   TEST_ASSERT(mol);
   TEST_ASSERT(RDKit::SubstructMatch(*mol, *patt, mV) == 3);
 
@@ -813,7 +815,7 @@ void test7() {
 
   delete mol;
   smi = "C[CH2+](C)C";
-  mol = RDKit::SmilesToMol(smi);
+  mol = RDKit::SmilesToMol(smi, debugParse, sanitize);
   TEST_ASSERT(mol);
   TEST_ASSERT(RDKit::SubstructMatch(*mol, *patt, mV) == 1);
 
@@ -825,7 +827,7 @@ void test7() {
 
   delete mol;
   smi = "C[CH3+2](C)C";
-  mol = RDKit::SmilesToMol(smi);
+  mol = RDKit::SmilesToMol(smi, debugParse, sanitize);
   TEST_ASSERT(mol);
   TEST_ASSERT(RDKit::SubstructMatch(*mol, *patt, mV) == 1);
 
@@ -836,7 +838,7 @@ void test7() {
 
   delete mol;
   smi = "C[CH2+](C)C";
-  mol = RDKit::SmilesToMol(smi);
+  mol = RDKit::SmilesToMol(smi, debugParse, sanitize);
   TEST_ASSERT(mol);
   TEST_ASSERT(RDKit::SubstructMatch(*mol, *patt, mV) == 0);
 
@@ -848,7 +850,7 @@ void test7() {
 
   delete mol;
   smi = "C[CH3+2](C)C";
-  mol = RDKit::SmilesToMol(smi);
+  mol = RDKit::SmilesToMol(smi, debugParse, sanitize);
   TEST_ASSERT(mol);
   TEST_ASSERT(RDKit::SubstructMatch(*mol, *patt, mV) == 1);
 
@@ -859,7 +861,7 @@ void test7() {
 
   delete mol;
   smi = "C[CH2+](C)C";
-  mol = RDKit::SmilesToMol(smi);
+  mol = RDKit::SmilesToMol(smi, debugParse, sanitize);
   TEST_ASSERT(mol);
   TEST_ASSERT(RDKit::SubstructMatch(*mol, *patt, mV) == 1);
 
@@ -871,7 +873,7 @@ void test7() {
 
   delete mol;
   smi = "C[CH3+2](C)C";
-  mol = RDKit::SmilesToMol(smi);
+  mol = RDKit::SmilesToMol(smi, debugParse, sanitize);
   TEST_ASSERT(mol);
   TEST_ASSERT(RDKit::SubstructMatch(*mol, *patt, mV) == 1);
 
@@ -882,7 +884,7 @@ void test7() {
 
   delete mol;
   smi = "C[CH2+](C)C";
-  mol = RDKit::SmilesToMol(smi);
+  mol = RDKit::SmilesToMol(smi, debugParse, sanitize);
   TEST_ASSERT(mol);
   TEST_ASSERT(RDKit::SubstructMatch(*mol, *patt, mV) == 3);
 
@@ -894,7 +896,7 @@ void test7() {
 
   delete mol;
   smi = "C[CH3+2](C)C";
-  mol = RDKit::SmilesToMol(smi);
+  mol = RDKit::SmilesToMol(smi, debugParse, sanitize);
   TEST_ASSERT(mol);
   TEST_ASSERT(RDKit::SubstructMatch(*mol, *patt, mV) == 4);
 
@@ -1262,91 +1264,6 @@ void test10() {
   BOOST_LOG(rdInfoLog) << "\tdone" << std::endl;
 }
 
-void test11() {
-  std::string pval, cip;
-  RDKit::RWMol *mol;
-  std::vector<RDKit::MatchVectType> mV;
-  std::string sln, smi;
-
-  BOOST_LOG(rdInfoLog) << "-------------------------------------" << std::endl;
-  BOOST_LOG(rdInfoLog) << "Test11: chiral SLNs " << std::endl;
-
-  sln = "CH(Cl)(F)Br";
-  mol = RDKit::SLNToMol(sln);
-  TEST_ASSERT(mol);
-  TEST_ASSERT(mol->getNumAtoms() == 4);
-  TEST_ASSERT(mol->getAtomWithIdx(0)->getChiralTag() ==
-              RDKit::Atom::CHI_UNSPECIFIED);
-
-  delete mol;
-  sln = "C[s=N]H(Cl)(F)Br";
-  mol = RDKit::SLNToMol(sln);
-  TEST_ASSERT(mol);
-  TEST_ASSERT(mol->getNumAtoms() == 4);
-  std::cerr << sln << " -> " << MolToSmiles(*mol, true) << " "
-            << mol->getNumAtoms() << std::endl;
-  smi = MolToSmiles(*mol, true);
-  // TEST_ASSERT(smi=="F[C@@H](Cl)Br");
-
-  delete mol;
-  sln = "ClC[s=i]H(F)Br";
-  mol = RDKit::SLNToMol(sln);
-  TEST_ASSERT(mol);
-  TEST_ASSERT(mol->getNumAtoms() == 4);
-// mol->debugMol(std::cerr);
-#if 0
-  RDKit::MolOps::assignAtomChiralCodes(*mol);
-  TEST_ASSERT(mol->getAtomWithIdx(1)->hasProp(RDKit::common_properties::_CIPCode));
-  mol->getAtomWithIdx(1)->getProp(RDKit::common_properties::_CIPCode,cip);
-  TEST_ASSERT(cip=="R");
-#endif
-  std::cerr << sln << " -> " << MolToSmiles(*mol, true) << " "
-            << mol->getNumAtoms() << std::endl;
-  smi = MolToSmiles(*mol, true);
-  // TEST_ASSERT(smi=="F[C@@H](Cl)Br");
-
-  delete mol;
-  sln = "FC[s=N]H(Cl)Br";
-  mol = RDKit::SLNToMol(sln);
-  TEST_ASSERT(mol);
-  std::cerr << sln << " -> " << MolToSmiles(*mol, true) << " "
-            << mol->getNumAtoms() << std::endl;
-  smi = MolToSmiles(*mol, true);
-  // TEST_ASSERT(smi=="F[C@@H](Cl)Br");
-
-  delete mol;
-  sln = "FC[s=N]H(Br)Cl";
-  mol = RDKit::SLNToMol(sln);
-  TEST_ASSERT(mol);
-  TEST_ASSERT(mol->getNumAtoms() == 4);
-  std::cerr << sln << " -> " << MolToSmiles(*mol, true) << " "
-            << mol->getNumAtoms() << std::endl;
-  smi = MolToSmiles(*mol, true);
-  // TEST_ASSERT(smi=="F[C@H](Cl)Br");
-
-  delete mol;
-  sln = "HC[s=N](Cl)(F)Br";
-  mol = RDKit::SLNToMol(sln);
-  TEST_ASSERT(mol);
-  TEST_ASSERT(mol->getNumAtoms() == 4);
-  std::cerr << sln << " -> " << MolToSmiles(*mol, true) << " "
-            << mol->getNumAtoms() << std::endl;
-  smi = MolToSmiles(*mol, true);
-  // TEST_ASSERT(smi=="F[C@@H](Cl)Br");
-
-  delete mol;
-  sln = "C[s=i]H(Cl)(F)Br";
-  mol = RDKit::SLNToMol(sln);
-  TEST_ASSERT(mol);
-  TEST_ASSERT(mol->getNumAtoms() == 4);
-  smi = MolToSmiles(*mol, true);
-  std::cerr << sln << " -> " << MolToSmiles(*mol, true) << " "
-            << mol->getNumAtoms() << std::endl;
-  // TEST_ASSERT(smi=="F[C@H](Cl)Br");
-
-  delete mol;
-  BOOST_LOG(rdInfoLog) << "\tdone" << std::endl;
-}
 
 void test12() {
   RDKit::RWMol *patt, *mol;
@@ -1969,7 +1886,6 @@ int main(int argc, char *argv[]) {
 // FIX: need a test for handling Hs in the SLN itself. This should be done for
 // both normal and query SLNs and must be done after the SLN parser handles
 // that case (errr, duh)
-#if 1
   test1();
   test2();
   test3();
@@ -1980,14 +1896,12 @@ int main(int argc, char *argv[]) {
   test8();
   test9();
   test10();
-  // test11();
   test12();
   test13();
   test14();
   test15();
   test16();
   test17();
-#endif
   testIssue277();
   testIssue278();
 }
