@@ -1,5 +1,5 @@
 //
-//  Copyright (C) 2002-2021 Greg Landrum and other RDKit contributors
+//  Copyright (C) 2002-2025 Greg Landrum and other RDKit contributors
 //
 //   @@ All Rights Reserved @@
 //  This file is part of the RDKit.
@@ -15,6 +15,7 @@
 #include <GraphMol/new_canon.h>
 #include <GraphMol/Chirality.h>
 #include <GraphMol/Atropisomers.h>
+#include <GraphMol/QueryOps.h>
 #include <GraphMol/FileParsers/MolFileStereochem.h>
 #include <RDGeneral/BoostStartInclude.h>
 #include <boost/dynamic_bitset.hpp>
@@ -33,69 +34,6 @@
 
 namespace RDKit {
 
-void updateSmilesWriteParamsFromJSON(SmilesWriteParams &params,
-                                     const char *details_json) {
-  if (details_json && strlen(details_json)) {
-    boost::property_tree::ptree pt;
-    std::istringstream ss;
-    ss.str(details_json);
-    boost::property_tree::read_json(ss, pt);
-    params.doIsomericSmiles =
-        pt.get("doIsomericSmiles", params.doIsomericSmiles);
-    params.doKekule = pt.get("doKekule", params.doKekule);
-    params.rootedAtAtom = pt.get("rootedAtAtom", params.rootedAtAtom);
-    params.canonical = pt.get("canonical", params.canonical);
-    params.allBondsExplicit =
-        pt.get("allBondsExplicit", params.allBondsExplicit);
-    params.allHsExplicit = pt.get("allHsExplicit", params.allHsExplicit);
-    params.doRandom = pt.get("doRandom", params.doRandom);
-  }
-}
-
-void updateSmilesWriteParamsFromJSON(SmilesWriteParams &params,
-                                     const std::string &details_json) {
-  updateSmilesWriteParamsFromJSON(params, details_json.c_str());
-}
-
-void updateCXSmilesFieldsFromJSON(SmilesWrite::CXSmilesFields &cxSmilesFields,
-                                  RestoreBondDirOption &restoreBondDirs,
-                                  const char *details_json) {
-  static const auto cxSmilesFieldsKeyValuePairs = CXSMILESFIELDS_ITEMS_MAP;
-  static const auto restoreBondDirOptionKeyValuePairs =
-      RESTOREBONDDIROPTION_ITEMS_MAP;
-  if (details_json && strlen(details_json)) {
-    boost::property_tree::ptree pt;
-    std::istringstream ss;
-    ss.str(details_json);
-    boost::property_tree::read_json(ss, pt);
-    auto cxSmilesFieldsFromJson =
-        static_cast<std::underlying_type<SmilesWrite::CXSmilesFields>::type>(
-            SmilesWrite::CXSmilesFields::CX_NONE);
-    for (const auto &keyValuePair : cxSmilesFieldsKeyValuePairs) {
-      cxSmilesFieldsFromJson |= (pt.get(keyValuePair.first, false)
-                                     ? keyValuePair.second
-                                     : SmilesWrite::CXSmilesFields::CX_NONE);
-    }
-    if (cxSmilesFieldsFromJson) {
-      cxSmilesFields =
-          static_cast<SmilesWrite::CXSmilesFields>(cxSmilesFieldsFromJson);
-    }
-    std::string restoreBondDirOption;
-    restoreBondDirOption = pt.get("restoreBondDirOption", restoreBondDirOption);
-    auto it = restoreBondDirOptionKeyValuePairs.find(restoreBondDirOption);
-    if (it != restoreBondDirOptionKeyValuePairs.end()) {
-      restoreBondDirs = it->second;
-    }
-  }
-}
-
-void updateCXSmilesFieldsFromJSON(SmilesWrite::CXSmilesFields &cxSmilesFields,
-                                  RestoreBondDirOption &restoreBondDirs,
-                                  const std::string &details_json) {
-  updateCXSmilesFieldsFromJSON(cxSmilesFields, restoreBondDirs,
-                               details_json.c_str());
-}
-
 namespace SmilesWrite {
 const int atomicSmiles[] = {0, 5, 6, 7, 8, 9, 15, 16, 17, 35, 53, -1};
 bool inOrganicSubset(int atomicNumber) {
@@ -151,6 +89,65 @@ std::string getAtomChiralityInfo(const Atom *atom) {
   }
   return atString;
 }
+
+// -----
+// figure out if we need to put a bracket around the atom,
+// the conditions for this are:
+//   - not in the organic subset
+//   - formal charge specified
+//   - chirality present and writing isomeric smiles
+//   - non-default isotope and writing isomeric smiles
+//   - atom-map information present
+//   - the atom has a nonstandard valence
+//   - bonded to a metal
+bool atomNeedsBracket(const Atom *atom, const std::string &atString,
+                      const SmilesWriteParams &params) {
+  PRECONDITION(atom, "null atom");
+  auto num = atom->getAtomicNum();
+  if (!inOrganicSubset(num)) {
+    return true;
+  }
+
+  if (atom->getFormalCharge()) {
+    return true;
+  }
+  if (params.doIsomericSmiles && (atom->getIsotope() || !atString.empty())) {
+    return true;
+  }
+  if (atom->hasProp(common_properties::molAtomMapNumber)) {
+    return true;
+  }
+
+  const INT_VECT &defaultVs = PeriodicTable::getTable()->getValenceList(num);
+  int totalValence = atom->getTotalValence();
+  bool nonStandard = false;
+  if (atom->getNumRadicalElectrons()) {
+    nonStandard = true;
+  } else if ((num == 7 || num == 15) && atom->getIsAromatic() &&
+             atom->getNumExplicitHs()) {
+    // another type of "nonstandard" valence is an aromatic N or P with
+    // explicit Hs indicated:
+    nonStandard = true;
+  } else {
+    nonStandard = (totalValence != defaultVs.front() && atom->getTotalNumHs());
+  }
+  if (nonStandard) {
+    return true;
+  }
+
+  // check for bonds to a metal
+  if (atom->hasOwningMol()) {
+    for (const auto bond : atom->getOwningMol().atomBonds(atom)) {
+      auto oatom = bond->getOtherAtom(atom);
+      if (QueryOps::isMetal(*oatom)) {
+        return true;
+      }
+    }
+  }
+
+  return false;
+}
+
 }  // namespace
 
 std::string GetAtomSmiles(const Atom *atom, const SmilesWriteParams &params) {
@@ -160,7 +157,6 @@ std::string GetAtomSmiles(const Atom *atom, const SmilesWriteParams &params) {
   int num = atom->getAtomicNum();
   int isotope = atom->getIsotope();
 
-  bool needsBracket = false;
   std::string symb;
   bool hasCustomSymbol =
       atom->getPropIfPresent(common_properties::smilesSymbol, symb);
@@ -176,41 +172,9 @@ std::string GetAtomSmiles(const Atom *atom, const SmilesWriteParams &params) {
       atString = getAtomChiralityInfo(atom);
     }
   }
-  if (!params.allHsExplicit && inOrganicSubset(num)) {
-    // it's a member of the organic subset
-
-    // -----
-    // figure out if we need to put a bracket around the atom,
-    // the conditions for this are:
-    //   - formal charge specified
-    //   - the atom has a nonstandard valence
-    //   - chirality present and writing isomeric smiles
-    //   - non-default isotope and writing isomeric smiles
-    //   - atom-map information present
-    const INT_VECT &defaultVs = PeriodicTable::getTable()->getValenceList(num);
-    int totalValence = atom->getTotalValence();
-    bool nonStandard = false;
-
-    if (hasCustomSymbol || atom->getNumRadicalElectrons()) {
-      nonStandard = true;
-    } else if ((num == 7 || num == 15) && atom->getIsAromatic() &&
-               atom->getNumExplicitHs()) {
-      // another type of "nonstandard" valence is an aromatic N or P with
-      // explicit Hs indicated:
-      nonStandard = true;
-    } else {
-      nonStandard =
-          (totalValence != defaultVs.front() && atom->getTotalNumHs());
-    }
-
-    if (fc || nonStandard ||
-        atom->hasProp(common_properties::molAtomMapNumber)) {
-      needsBracket = true;
-    } else if (params.doIsomericSmiles && (isotope || atString != "")) {
-      needsBracket = true;
-    }
-  } else {
-    needsBracket = true;
+  bool needsBracket = true;
+  if (!hasCustomSymbol && !params.allHsExplicit) {
+    needsBracket = atomNeedsBracket(atom, atString, params);
   }
   if (needsBracket) {
     res += "[";
@@ -801,13 +765,21 @@ std::string MolToCXSmiles(const ROMol &romol,
       if (!canHaveDirection(*bond)) {
         continue;
       }
-      if (bond->getBondDir() != Bond::BondDir::NONE) {
-        bond->setBondDir(Bond::BondDir::NONE);
-      }
-      unsigned int cfg;
-      if (bond->getPropIfPresent<unsigned int>(
-              common_properties::_MolFileBondCfg, cfg)) {
-        bond->clearProp(common_properties::_MolFileBondCfg);
+
+      // we want to preserve wiggly bond information for discovery by
+      // CXSmilesOps::get_bond_config_block
+      using RDKit::common_properties::_MolFileBondCfg;
+      // this is a wiggly bond
+      if (auto cfg = 0u;
+          bond->getPropIfPresent<unsigned int>(_MolFileBondCfg, cfg) &&
+          cfg == 2) {
+        bond->setBondDir(Bond::BondDir::UNKNOWN);
+      } else {
+        if (bond->getBondDir() != Bond::BondDir::NONE) {
+          bond->setBondDir(Bond::BondDir::NONE);
+        }
+
+        bond->clearProp(_MolFileBondCfg);
       }
     }
   }
