@@ -512,14 +512,9 @@ std::vector<MatchVectType> SubstructMatch(
   MolMatchFinalCheckFunctor matchChecker(query, mol, params);
 
   std::vector<detail::ssPairType> pms;
-#if 0
-  bool found=boost::ullmann_all(query.getTopology(),mol.getTopology(),
-				atomLabeler,bondLabeler,pms);
-#else
   bool found =
       boost::vf2_all(query.getTopology(), mol.getTopology(), atomLabeler,
                      bondLabeler, matchChecker, pms, params.maxMatches);
-#endif
   if (found) {
     unsigned int nQueryAtoms = query.getNumAtoms();
     matches.reserve(pms.size());
@@ -638,14 +633,9 @@ unsigned int RecursiveMatcher(const ROMol &mol, const ROMol &query,
   matches.clear();
   matches.resize(0);
   std::vector<detail::ssPairType> pms;
-#if 0
-      bool found=boost::ullmann_all(query.getTopology(),mol.getTopology(),
-				    atomLabeler,bondLabeler,pms);
-#else
   bool found =
       boost::vf2_all(query.getTopology(), mol.getTopology(), atomLabeler,
                      bondLabeler, matchChecker, pms, lparams.maxMatches);
-#endif
   unsigned int res = 0;
   if (found) {
     matches.reserve(pms.size());
