@@ -259,7 +259,7 @@ void SubSearcher(const Query &in_query, const Bits &bits,
       continue;
     }
     if (needs_rings &&
-        (!mol->getRingInfo() || !mol->getRingInfo()->isInitialized())) {
+        (!mol->getRingInfo() || !mol->getRingInfo()->isSymmSssr())) {
       MolOps::symmetrizeSSSR(*mol);
     }
 
