@@ -27,9 +27,12 @@ class ROMol;
 
 namespace SynthonSpaceSearch {
 class Synthon;
+class SynthonSpace;
 struct SynthonSpaceSearchParams;
 
-// This class holds all the synthons for a particular reaction.
+// This class holds pointers to all the synthons for a particular
+// reaction.  The synthons themselves are in a pool in the
+// SynthonSpace.
 class RDKIT_SYNTHONSPACESEARCH_EXPORT SynthonSet {
  public:
   SynthonSet() = default;
@@ -38,8 +41,8 @@ class RDKIT_SYNTHONSPACESEARCH_EXPORT SynthonSet {
   SynthonSet(SynthonSet &&rhs) = delete;
 
   const std::string &getId() const { return d_id; }
-  const std::vector<std::vector<std::unique_ptr<Synthon>>> &getSynthons()
-      const {
+  const std::vector<std::vector<std::pair<std::string, Synthon *>>> &
+  getSynthons() const {
     return d_synthons;
   }
   const boost::dynamic_bitset<> &getConnectors() const { return d_connectors; }
@@ -48,24 +51,26 @@ class RDKIT_SYNTHONSPACESEARCH_EXPORT SynthonSet {
     return d_synthConnPatts;
   }
   const std::vector<std::shared_ptr<ROMol>> &getConnectorRegions() const;
-
-  const std::unique_ptr<ExplicitBitVect> &getConnRegFP() const;
+  const std::vector<std::string> &getConnectorRegionSmiles() const;
+  const std::vector<std::unique_ptr<ExplicitBitVect>> &getConnRegFPs() const;
   const std::unique_ptr<ExplicitBitVect> &getAddFP() const;
   const std::unique_ptr<ExplicitBitVect> &getSubtractFP() const;
   const std::vector<int> &getNumConnectors() const;
+  std::uint64_t getNumProducts() const;
   bool hasFingerprints() const;
   bool hasAddAndSubtractFPs() const;
 
-  const std::vector<std::vector<std::unique_ptr<ExplicitBitVect>>> &
-  getSynthonFPs() const;
   // Writes to/reads from a binary stream.
   void writeToDBStream(std::ostream &os) const;
-  void readFromDBStream(std::istream &is, std::uint32_t version);
+  void readFromDBStream(std::istream &is, const SynthonSpace &space,
+                        std::uint32_t version);
   // write the enumerated molecules to the stream in SMILES format.
   void enumerateToStream(std::ostream &os) const;
 
-  // SynthonSet takes control of the newSynthon and manages it.
-  void addSynthon(int synthonSetNum, std::unique_ptr<Synthon> newSynthon);
+  // This stores the pointer to the Synthon, but doesn't manage
+  // it and should never delete it.
+  void addSynthon(int synthonSetNum, Synthon *newSynthon,
+                  const std::string &synthonId);
 
   // Sometimes the synthon sets are numbered from 1 in the text file,
   // in which case there'll be an empty set 0.
@@ -74,8 +79,9 @@ class RDKIT_SYNTHONSPACESEARCH_EXPORT SynthonSet {
   // The bonds in the synthons may not be the same as in the products, and
   // this is a problem for aromatic ring creation in particular.  Such as:
   // [1*]=CC=C[2*] and [1*]Nc1c([2*])cccc1 giving c1ccc2ncccc2c1.  So
-  // transfer the types of bonds from the products to the synthons.
-  void transferProductBondsToSynthons();
+  // make versions of the synthons that reflect this, storead as searchMol
+  // in each synthon.
+  void makeSynthonSearchMols();
 
   // Build the connector regions and their fingerprints.  Only used when
   // creating a SynthonSpace from a text file.
@@ -90,7 +96,8 @@ class RDKIT_SYNTHONSPACESEARCH_EXPORT SynthonSet {
 
   void buildSynthonFingerprints(
       const FingerprintGenerator<std::uint64_t> &fpGen);
-  void buildAddAndSubtractFPs(const FingerprintGenerator<std::uint64_t> &fpGen);
+  void buildAddAndSubtractFPs(const FingerprintGenerator<std::uint64_t> &fpGen,
+                              unsigned int numBits);
 
   // Return the molecules for synthons for which the bits are true.
   // Obviously requires that reqSynths is the same dimensions as
@@ -105,24 +112,30 @@ class RDKIT_SYNTHONSPACESEARCH_EXPORT SynthonSet {
  private:
   std::string d_id;
   // The lists of synthons.  A product of the reaction is created by
-  // combining 1 synthon from each of the outer vectors.
-  std::vector<std::vector<std::unique_ptr<Synthon>>> d_synthons;
-  // 4 bits showing which connectors are present in all the
+  // combining 1 synthon from each of the outer vectors.  The actual
+  // Synthon objects are held in the SynthonSpace which manages all
+  // the memory.  In different reactions/SynthonSets the same Synthon
+  // can have different IDs, so we need to keep the ID here rather
+  // than in the Synthon, whose primary key is its SMILES string.
+  std::vector<std::vector<std::pair<std::string, Synthon *>>> d_synthons;
+  // MAX_CONNECTOR_NUM+1 bits showing which connectors are present in all the
   // synthon sets.
   boost::dynamic_bitset<> d_connectors;
-  // and the connector patterns for each synthon set.
+  // And the connector patterns for each synthon set. If synthon set 0
+  // has connectors 1 and 3, then d_synthConnPatts[0] will have bits
+  // 1 and 3 set.
   std::vector<boost::dynamic_bitset<>> d_synthConnPatts;
 
   // The connector regions of a molecule are the pieces of up to 3 bonds from
   // a connector atom into the molecule.  We keep a vector of all the ones
-  // present in the synthons in the set, plus a fingerprint of all their
-  // fingerprints folded into 1.  If a query fragment doesn't have a
-  // connector region in common with any of the synthons it can be assumed that
-  // the fragment won't have a match in this SynthonSet.
+  // present in the synthons in the set, plus a fingerprint for each.
+  // If a query fragment doesn't have a connector region in common with
+  // any of the synthons it can be assumed that the fragment won't have
+  // a match in this SynthonSet.
   std::vector<std::shared_ptr<ROMol>> d_connectorRegions;
-  // The fingerprint of the connector regions.  Fingerprints for all
-  // connector regions are folded into the same fingerprint.
-  std::unique_ptr<ExplicitBitVect> d_connRegFP;
+  std::vector<std::string> d_connRegSmis;
+  // The fingerprints of the connector regions.
+  std::vector<std::unique_ptr<ExplicitBitVect>> d_connRegFPs;
 
   // When doing an approximate FP similarity by ORing together
   // the synthonFPs, adding d_addFP and subtracting d_subtractFP
@@ -133,15 +146,6 @@ class RDKIT_SYNTHONSPACESEARCH_EXPORT SynthonSet {
 
   // The number of connectors in the synthons in each synthon set.
   std::vector<int> d_numConnectors;
-
-  // The fingerprints for the synthons for use with a fingerprint similarity
-  // search. They are not properties of the Synthons because they are not
-  // generated directly from them, as explained in buildSynthonFingerprints.
-  std::vector<std::vector<std::unique_ptr<ExplicitBitVect>>> d_synthonFPs;
-
-  // Tag each atom and bond in each synthon with its index and the synthon
-  // set number it came from.
-  void tagSynthonAtomsAndBonds() const;
 };
 
 }  // namespace SynthonSpaceSearch
