@@ -14,7 +14,9 @@
 #include <chrono>
 #include <vector>
 
+#include <GraphMol/SynthonSpaceSearch/SynthonSpaceHitSet.h>
 #include <RDGeneral/export.h>
+#include <DataStructs/ExplicitBitVect.h>
 
 using Clock = std::chrono::steady_clock;
 using TimePoint = std::chrono::time_point<Clock>;
@@ -31,22 +33,20 @@ combMFromN(unsigned int m, unsigned int n);
 // Find all permutations of M things selected from N.
 RDKIT_SYNTHONSPACESEARCH_EXPORT std::vector<std::vector<unsigned int>>
 permMFromN(unsigned int m, unsigned int n);
-RDKIT_SYNTHONSPACESEARCH_EXPORT void fixAromaticRingSplits(
-    std::vector<std::unique_ptr<ROMol>> &molFrags);
 
-// Split the molecule into fragments.  maxBondSplits gives the maximum number
-// of bonds to be used in each split.  There will a vector of vectors of
-// molecules, 1 inner vector for each split i.e. maxBondSplits in total, the
-// first with 1 split, the 2nd with 2 etc.  Each inner vector contains the
-// fragments from a split molecule.  The maxBondSplits will be constrained to
-// between 1 and 4 inclusive, so if it is supplied outside that range, it will
-// be altered.  Also, you can't split a molecule on 3 bonds if it only contains
-// 2.
+// Split the molecule into fragments.  maxNumFrags gives the maximum number
+// of fragments to be produced in each set.  There will a vector of vectors of
+// molecules.  Each inner vector contains the fragments from a split molecule.
+// The maxNumFrags will be constrained to the maximum number of synthons in
+// the search space as there's no point making more fragments than that.
+// Any complex query atoms will be stripped out of the fragments and replaced
+// by a simple atom query.
 RDKIT_SYNTHONSPACESEARCH_EXPORT std::vector<std::vector<std::unique_ptr<ROMol>>>
-splitMolecule(const ROMol &query, unsigned int maxBondSplits,
-              std::uint64_t maxNumFrags, TimePoint *endTime, bool &timedOut);
+splitMolecule(const ROMol &query, unsigned int maxNumFrags,
+              const std::uint64_t maxNumFragSets, const TimePoint *endTime,
+              const int numThreads, bool &timedOut);
 // Counts the number of [1*], [2*]...[4*] in the string.
-RDKIT_SYNTHONSPACESEARCH_EXPORT int countConnections(const ROMol &frag);
+RDKIT_SYNTHONSPACESEARCH_EXPORT int countConnections(const ROMol &mol);
 
 // Return a bitset for each fragment giving the connector patterns
 RDKIT_SYNTHONSPACESEARCH_EXPORT std::vector<boost::dynamic_bitset<>>
@@ -57,22 +57,31 @@ getConnectorPatterns(const std::vector<std::unique_ptr<ROMol>> &fragSet);
 RDKIT_SYNTHONSPACESEARCH_EXPORT boost::dynamic_bitset<> getConnectorPattern(
     const std::vector<std::unique_ptr<ROMol>> &fragSet);
 
-// Return copies of the mol fragments will all permutations of the connectors
-// in the reaction onto the connectors in the fragments.
+// Gets the permutations of connector numbers and the atoms they should
+// be applied to in the molFrags.
 // E.g. if the reaction has 3 connectors, 1, 2 and 3 and the fragged mol has
 // 2, return all permutations of 2 from 3.  It's ok if the fragged mol doesn't
 // have all the connections in the reaction, although this may well result in
 // a lot of hits.
-RDKIT_SYNTHONSPACESEARCH_EXPORT std::vector<std::vector<std::unique_ptr<ROMol>>>
+RDKIT_SYNTHONSPACESEARCH_EXPORT
+std::vector<std::vector<std::vector<std::pair<Atom *, unsigned int>>>>
 getConnectorPermutations(const std::vector<std::unique_ptr<ROMol>> &molFrags,
                          const boost::dynamic_bitset<> &fragConns,
                          const boost::dynamic_bitset<> &reactionConns);
 
+// As above, but just returns the bitsets for the connector permutations,
+// not the molecules.
+RDKIT_SYNTHONSPACESEARCH_EXPORT
+std::vector<std::vector<boost::dynamic_bitset<>>> getConnectorPermutations(
+    const std::vector<boost::dynamic_bitset<>> &fragConnPatts,
+    const boost::dynamic_bitset<> &reactionConns);
+
 // If all bits in one of the bitsets is unset, it means that nothing matched
 // that synthon.  If at least one of the bitsets has a set bit, all products
 // incorporating the synthon with no bits set must match the query so
 // should be used because the query matches products that don't incorporate
-// anything from 1 of the synthon lists.  For example, if the synthons are
+// anything from 1 of the synthon lists. Therefore those bits will all be
+// set on exit.  For example, if the synthons are
 // [1*]Nc1c([2*])cccc1 and [1*]=CC=C[2*] and the query is c1ccccc1.
 RDKIT_SYNTHONSPACESEARCH_EXPORT void expandBitSet(
     std::vector<boost::dynamic_bitset<>> &bitSets);
@@ -111,6 +120,44 @@ struct RDKIT_SYNTHONSPACESEARCH_EXPORT Stepper {
   std::vector<size_t> d_sizes;
 };
 
+// Return a molecule containing the portions of the molecule starting at
+// each dummy atom and going out up to 3 bonds.  There may be more than
+// 1 fragment if there are dummy atoms more than 3 bonds apart, and there
+// may be fragments with more than 1 dummy atom if their dummy atoms fall
+// within 3 bonds of each other.  E.g. the molecule [1*]CN(C[2*])Cc1ccccc1
+// will give [1*]CN(C)C[1*].  The 2 dummy atoms are 4 bonds apart, but the
+// fragments overlap.  All dummy atoms given isotope 1 whatever they had
+// before.
+RDKIT_SYNTHONSPACESEARCH_EXPORT std::unique_ptr<ROMol> buildConnRegion(
+    const ROMol &mol);
+
+// Take any query atoms out of the molecule, replacing them with the
+// nearest thing possible.  Probably this will just be the atomic
+// number.  It doesn't change dummy atoms that have an isotope as
+// these will be connectors, or anything with an AtomType query as
+// they are uncontroversial. Returns true if it did something,
+// false if the molecule was left unchanged.
+RDKIT_SYNTHONSPACESEARCH_EXPORT bool removeQueryAtoms(RWMol &mol);
+
+// Put together a product name in the Enamine style, which uses
+// a semicolon as a separator and has the reagents names followed
+// by the reaction name.
+RDKIT_SYNTHONSPACESEARCH_EXPORT std::string buildProductName(
+    const std::string &reactionId, const std::vector<std::string> &fragIds);
+RDKIT_SYNTHONSPACESEARCH_EXPORT std::string buildProductName(
+    const RDKit::SynthonSpaceSearch::SynthonSpaceHitSet *hitset,
+    const std::vector<size_t> &fragNums);
+// Zip the fragments together to make a molecule.  Assumes the connection
+// points are marking by isotope numbers on dummy atoms.
+RDKIT_SYNTHONSPACESEARCH_EXPORT std::unique_ptr<ROMol> buildProduct(
+    const std::vector<const ROMol *> &synthons);
+
+// Make a map that has all the fragments with the same SMILES
+// in a vector keyed by that SMILES.
+RDKIT_SYNTHONSPACESEARCH_EXPORT std::map<std::string, std::vector<ROMol *>>
+mapFragsBySmiles(std::vector<std::vector<std::unique_ptr<ROMol>>> &fragSets,
+                 bool &cancelled);
+
 }  // namespace SynthonSpaceSearch::details
 }  // namespace RDKit
 
