@@ -14,6 +14,7 @@
 #include <RDBoost/Wrap.h>
 
 #include <GraphMol/ROMol.h>
+#include <GraphMol/RascalMCES/RascalOptions.h>
 #include <GraphMol/SynthonSpaceSearch/SynthonSpace.h>
 
 namespace python = boost::python;
@@ -50,9 +51,38 @@ struct SearchResults_wrapper {
   }
 };
 
-SynthonSpaceSearch::SearchResults substructureSearch_helper(
+SynthonSpaceSearch::SearchResults substructureSearch_helper1(
     SynthonSpaceSearch::SynthonSpace &self, const ROMol &query,
-    const python::object &py_params) {
+    const python::object &py_smParams, const python::object &py_params) {
+  SynthonSpaceSearch::SynthonSpaceSearchParams params;
+  SubstructMatchParameters smParams;
+  if (!py_smParams.is_none()) {
+    smParams = python::extract<SubstructMatchParameters>(py_smParams);
+  }
+  if (!py_params.is_none()) {
+    params = python::extract<SynthonSpaceSearch::SynthonSpaceSearchParams>(
+        py_params);
+  }
+
+  SynthonSpaceSearch::SearchResults results;
+  {
+    NOGIL gil;
+    results = self.substructureSearch(query, smParams, params);
+  }
+  if (results.getCancelled()) {
+    throw_runtime_error("SubstructureSearch cancelled");
+  }
+  return results;
+}
+
+SynthonSpaceSearch::SearchResults substructureSearch_helper2(
+    SynthonSpaceSearch::SynthonSpace &self,
+    const GeneralizedSubstruct::ExtendedQueryMol &query,
+    const python::object &py_smParams, const python::object &py_params) {
+  SubstructMatchParameters smParams;
+  if (!py_smParams.is_none()) {
+    smParams = python::extract<SubstructMatchParameters>(py_smParams);
+  }
   SynthonSpaceSearch::SynthonSpaceSearchParams params;
   if (!py_params.is_none()) {
     params = python::extract<SynthonSpaceSearch::SynthonSpaceSearchParams>(
@@ -61,7 +91,7 @@ SynthonSpaceSearch::SearchResults substructureSearch_helper(
   SynthonSpaceSearch::SearchResults results;
   {
     NOGIL gil;
-    results = self.substructureSearch(query, params);
+    results = self.substructureSearch(query, smParams, params);
   }
   if (results.getCancelled()) {
     throw_runtime_error("SubstructureSearch cancelled");
@@ -92,10 +122,53 @@ SynthonSpaceSearch::SearchResults fingerprintSearch_helper(
   return results;
 }
 
-void summariseHelper(const SynthonSpaceSearch::SynthonSpace &self) {
+SynthonSpaceSearch::SearchResults rascalSearch_helper(
+    SynthonSpaceSearch::SynthonSpace &self, const ROMol &query,
+    const python::object &py_rascalOptions, const python::object &py_params) {
+  RascalMCES::RascalOptions rascalOptions;
+  rascalOptions = python::extract<RascalMCES::RascalOptions>(py_rascalOptions);
+  SynthonSpaceSearch::SynthonSpaceSearchParams params;
+  if (!py_params.is_none()) {
+    params = python::extract<SynthonSpaceSearch::SynthonSpaceSearchParams>(
+        py_params);
+  }
+  {
+    NOGIL gil;
+    return self.rascalSearch(query, rascalOptions, params);
+  }
+}
+
+void summariseHelper(SynthonSpaceSearch::SynthonSpace &self) {
   self.summarise(std::cout);
 }
 
+void convertTextToDBFile_helper(const std::string &inFilename,
+                                const std::string &outFilename,
+                                python::object fpGen) {
+  const FingerprintGenerator<std::uint64_t> *fpGenCpp = nullptr;
+  if (fpGen) {
+    fpGenCpp = python::extract<FingerprintGenerator<std::uint64_t> *>(fpGen);
+  }
+  bool cancelled = false;
+  SynthonSpaceSearch::convertTextToDBFile(inFilename, outFilename, cancelled,
+                                          fpGenCpp);
+  if (cancelled) {
+    throw_runtime_error("Database conversion cancelled");
+  }
+}
+
+void readTextFile_helper(SynthonSpaceSearch::SynthonSpace &self,
+                         const std::string &inFilename) {
+  bool cancelled = false;
+  {
+    NOGIL gil;
+    self.readTextFile(inFilename, cancelled);
+  }
+  if (cancelled) {
+    throw_runtime_error("Database read cancelled.");
+  }
+}
+
 BOOST_PYTHON_MODULE(rdSynthonSpaceSearch) {
   python::scope().attr("__doc__") =
       "Module containing implementation of SynthonSpace search of"
@@ -109,19 +182,13 @@ BOOST_PYTHON_MODULE(rdSynthonSpaceSearch) {
   python::class_<SynthonSpaceSearch::SynthonSpaceSearchParams,
                  boost::noncopyable>("SynthonSpaceSearchParams",
                                      docString.c_str())
-      .def_readwrite(
-          "maxBondSplits",
-          &SynthonSpaceSearch::SynthonSpaceSearchParams::maxBondSplits,
-          "The maximum number of bonds to break in the query."
-          "  It should be between 1 and 4 and will be constrained to be so."
-          "  Default=4.")
       .def_readwrite("maxHits",
                      &SynthonSpaceSearch::SynthonSpaceSearchParams::maxHits,
                      "The maximum number of hits to return.  Default=1000."
                      "Use -1 for no maximum.")
       .def_readwrite(
           "maxNumFrags",
-          &SynthonSpaceSearch::SynthonSpaceSearchParams::maxNumFrags,
+          &SynthonSpaceSearch::SynthonSpaceSearchParams::maxNumFragSets,
           "The maximum number of fragments the query can be broken into."
           "  Big molecules will create huge numbers of fragments that may cause"
           " excessive memory use.  If the number of fragments hits this number,"
@@ -182,17 +249,27 @@ BOOST_PYTHON_MODULE(rdSynthonSpaceSearch) {
       .def_readwrite(
           "timeOut", &SynthonSpaceSearch::SynthonSpaceSearchParams::timeOut,
           "Time limit for search, in seconds.  Default is 600s, 0 means no"
-          " timeout.  Requires an integer");
+          " timeout.  Requires an integer")
+      .def_readwrite(
+          "numThreads",
+          &SynthonSpaceSearch::SynthonSpaceSearchParams::numThreads,
+          "The number of threads to use for search.  If > 0, will use that"
+          " number.  If <= 0, will use the number of hardware"
+          " threads plus this number.  So if the number of"
+          " hardware threads is 8, and numThreads is -1, it will"
+          " use 7 threads.  Default=1.");
 
   docString = "SynthonSpaceSearch object.";
   python::class_<SynthonSpaceSearch::SynthonSpace, boost::noncopyable>(
       "SynthonSpace", docString.c_str(), python::init<>())
-      .def("ReadTextFile", &SynthonSpaceSearch::SynthonSpace::readTextFile,
+      .def("ReadTextFile", &readTextFile_helper,
            (python::arg("self"), python::arg("inFile")),
            "Reads text file of the sort used by ChemSpace/Enamine.")
       .def("ReadDBFile", &SynthonSpaceSearch::SynthonSpace::readDBFile,
-           (python::arg("self"), python::arg("inFile")),
-           "Reads binary database file.")
+           (python::arg("self"), python::arg("inFile"),
+            python::arg("numThreads") = 1),
+           "Reads binary database file.  Takes optional number of threads,"
+           "default=1.")
       .def("WriteDBFile", &SynthonSpaceSearch::SynthonSpace::writeDBFile,
            (python::arg("self"), python::arg("outFile")),
            "Writes binary database file.")
@@ -210,16 +287,35 @@ BOOST_PYTHON_MODULE(rdSynthonSpaceSearch) {
            " counting of any duplicates.")
       .def("Summarise", &summariseHelper, python::arg("self"),
            "Writes a summary of the SynthonSpace to stdout.")
-      .def("SubstructureSearch", &substructureSearch_helper,
+      .def("GetSynthonFingerprintType",
+           &SynthonSpaceSearch::SynthonSpace::getSynthonFingerprintType,
+           python::arg("self"),
+           "Returns the information string for the fingerprint generator"
+           " used to create this space.")
+      .def("SubstructureSearch", &substructureSearch_helper1,
            (python::arg("self"), python::arg("query"),
+            python::arg("substructMatchParams") = python::object(),
             python::arg("params") = python::object()),
            "Does a substructure search in the SynthonSpace.")
+      .def("SubstructureSearch", &substructureSearch_helper2,
+           (python::arg("self"), python::arg("query"),
+            python::arg("substructMatchParams") = python::object(),
+            python::arg("params") = python::object()),
+           "Does a substructure search in the SynthonSpace using an"
+           " extended query.")
       .def("FingerprintSearch", &fingerprintSearch_helper,
            (python::arg("self"), python::arg("query"),
             python::arg("fingerprintGenerator"),
             python::arg("params") = python::object()),
            "Does a fingerprint search in the SynthonSpace using the"
            " FingerprintGenerator passed in.")
+      .def("RascalSearch", &rascalSearch_helper,
+           (python::arg("self"), python::arg("query"),
+            python::arg("rascalOptions"),
+            python::arg("params") = python::object()),
+           "Does a search using the Rascal similarity score.  The similarity"
+           " threshold used is provided by rascalOptions, and the one in"
+           " params is ignored.")
       .def(
           "BuildSynthonFingerprints",
           &SynthonSpaceSearch::SynthonSpace::buildSynthonFingerprints,
@@ -228,6 +324,25 @@ BOOST_PYTHON_MODULE(rdSynthonSpaceSearch) {
           " is done automatically when the first similarity search is done, but if"
           " converting a text file to binary format it might need to be done"
           " explicitly.");
+
+  docString =
+      "Convert the text file into the binary DB file in our format."
+      "  Assumes that all synthons from a reaction are contiguous in the input file."
+      "  This uses a lot less memory than using ReadTextFile() followed by"
+      "  WriteDBFile()."
+      "- inFilename the name of the text file"
+      "- outFilename the name of the binary file"
+      "- optional fingerprint generator";
+  python::def("ConvertTextToDBFile", &RDKit::convertTextToDBFile_helper,
+              (python::arg("inFilename"), python::arg("outFilename"),
+               python::arg("fpGen") = python::object()),
+              docString.c_str());
+
+  docString =
+      "Format an integer with spaces every 3 digits for ease of reading";
+  python::def("FormattedIntegerString",
+              &RDKit::SynthonSpaceSearch::formattedIntegerString,
+              python::arg("value"), docString.c_str());
 }
 
 }  // namespace RDKit
\ No newline at end of file
