@@ -37,8 +37,9 @@ import unittest
 
 from pathlib import Path
 
-from rdkit import Chem
-from rdkit.Chem import rdSynthonSpaceSearch, rdFingerprintGenerator
+from rdkit import Chem, rdBase
+from rdkit.Chem import (rdSynthonSpaceSearch, rdFingerprintGenerator,
+                        rdRascalMCES, rdGeneralizedSubstruct)
 
 
 class TestCase(unittest.TestCase):
@@ -47,26 +48,32 @@ class TestCase(unittest.TestCase):
     self.sssDir = Path(os.environ["RDBASE"]) / "Code" / "GraphMol" / "SynthonSpaceSearch" / "data"
 
   def testSubstructSearch(self):
-    fName = self.sssDir / "Syntons_5567.csv"
+    fName = self.sssDir / "idorsia_toy_space_a.spc"
     synthonspace = rdSynthonSpaceSearch.SynthonSpace()
-    synthonspace.ReadTextFile(fName)
-    self.assertEqual(10, synthonspace.GetNumReactions())
+    synthonspace.ReadDBFile(fName)
     params = rdSynthonSpaceSearch.SynthonSpaceSearchParams()
     params.maxHits = 10
-    results = synthonspace.SubstructureSearch(Chem.MolFromSmarts("c1ccccc1C(=O)N1CCCC1"), params)
+    results = synthonspace.SubstructureSearch(Chem.MolFromSmarts("c1ccccc1C(=O)N1CCCC1"), params=params)
+    self.assertEqual(10, len(results.GetHitMolecules()))
+    smParams = Chem.SubstructMatchParameters()
+    results = synthonspace.SubstructureSearch(Chem.MolFromSmarts("c1ccccc1C(=O)N1CCCC1"),
+                                              substructMatchParams=smParams,
+                                              params=params)
     self.assertEqual(10, len(results.GetHitMolecules()))
 
   def testFingerprintSearch(self):
-    fName = self.sssDir / "Syntons_5567.csv"
+    fName = self.sssDir / "idorsia_toy_space_a.spc"
     synthonspace = rdSynthonSpaceSearch.SynthonSpace()
-    synthonspace.ReadTextFile(fName)
-    self.assertEqual(10, synthonspace.GetNumReactions())
+    synthonspace.ReadDBFile(fName)
+    self.assertEqual(6, synthonspace.GetNumReactions())
     params = rdSynthonSpaceSearch.SynthonSpaceSearchParams()
-    params.maxHits = 10
+    params.maxHits = -1
+    params.similarityCutoff = 0.45
     fpgen = rdFingerprintGenerator.GetRDKitFPGenerator(fpSize=2048, useBondOrder=True)
     results = synthonspace.FingerprintSearch(
-      Chem.MolFromSmiles("c12ccc(C)cc1[nH]nc2C(=O)NCc1cncs1"), fpgen, params)
-    self.assertEqual(10, len(results.GetHitMolecules()))
+      Chem.MolFromSmiles("O=C(Nc1c(CNC=O)cc[s]1)c1nccnc1"), fpgen, params)
+    self.assertEqual(278, len(results.GetHitMolecules()))
+    
 
   def testEnumerate(self):
     fName = self.sssDir / "amide_space.txt"
@@ -76,20 +83,15 @@ class TestCase(unittest.TestCase):
       synthonspace.WriteEnumeratedFile(tmp.name)
 
   def testTimeOut(self):
-    fName = self.sssDir / "Syntons_5567.csv"
+    fName = self.sssDir / "idorsia_toy_space_a.spc"
     synthonspace = rdSynthonSpaceSearch.SynthonSpace()
-    synthonspace.ReadTextFile(fName)
-    self.assertEqual(10, synthonspace.GetNumReactions())
+    synthonspace.ReadDBFile(fName)
     params = rdSynthonSpaceSearch.SynthonSpaceSearchParams()
-    params.timeOut = 50
+    params.timeOut = 1
+    params.maxHits = -1
     params.similarityCutoff = 0.3
     params.fragSimilarityAdjuster = 0.3
     fpgen = rdFingerprintGenerator.GetRDKitFPGenerator(fpSize=2048, useBondOrder=True)
-    results = synthonspace.FingerprintSearch(
-      Chem.MolFromSmiles("c12ccc(C)cc1[nH]nc2C(=O)NCc1cncs1"), fpgen, params)
-    self.assertFalse(results.GetTimedOut())
-
-    params.timeOut = 1
     results = synthonspace.FingerprintSearch(
       Chem.MolFromSmiles("c12ccc(C)cc1[nH]nc2C(=O)NCc1cncs1"), fpgen, params)
     self.assertTrue(results.GetTimedOut())
@@ -103,6 +105,28 @@ class TestCase(unittest.TestCase):
     synthonspace = rdSynthonSpaceSearch.SynthonSpace()
     self.assertRaises(RuntimeError, synthonspace.ReadTextFile, fName)
 
+  def testRascalSearch(self):
+    fName = self.sssDir / "Syntons_5567.csv"
+    synthonspace = rdSynthonSpaceSearch.SynthonSpace()
+    synthonspace.ReadTextFile(fName)
+    self.assertEqual(10, synthonspace.GetNumReactions())
+    params = rdSynthonSpaceSearch.SynthonSpaceSearchParams()
+    params.maxHits = 10
+    rascalOpts = rdRascalMCES.RascalOptions()
+    results = synthonspace.RascalSearch(Chem.MolFromSmiles("c12ccc(C)cc1[nH]nc2C(=O)NCc1cncs1"),
+                                             rascalOpts, params)
+    self.assertEqual(10, len(results.GetHitMolecules()))
 
+  def testExtendedSubsructureSearch(self):
+    fName = self.sssDir / "extended_query.csv"
+    synthonspace = rdSynthonSpaceSearch.SynthonSpace()
+    synthonspace.ReadTextFile(fName)
+    self.assertEqual(7, synthonspace.GetNumReactions())
+    m = Chem.MolFromSmarts('[#6]-*.c1nc2cccnc2n1 |m:1:3.10|')
+    xqry = rdGeneralizedSubstruct.CreateExtendedQueryMol(m)
+    results = synthonspace.SubstructureSearch(xqry)
+    self.assertEqual(12, len(results.GetHitMolecules()))
+  
+    
 if __name__ == "__main__":
   unittest.main()
