@@ -9,6 +9,7 @@
 
 #include <algorithm>
 #include <chrono>
+#include <filesystem>
 #include <fstream>
 
 #include <GraphMol/SubstructLibrary/SubstructLibrary.h>
@@ -92,9 +93,9 @@ TEST_CASE("FP Small tests") {
 
   for (size_t i = 0; i < libNames.size(); i++) {
     SynthonSpace synthonspace;
-    synthonspace.readTextFile(libNames[i]);
+    bool cancelled = false;
+    synthonspace.readTextFile(libNames[i], cancelled);
     SynthonSpaceSearchParams params;
-    params.maxBondSplits = 3;
     params.randomSeed = 1;
     params.approxSimilarityAdjuster = 0.2;
     auto queryMol = v2::SmilesParse::MolFromSmiles(querySmis[i]);
@@ -131,157 +132,47 @@ TEST_CASE("FP Small tests") {
   }
 }
 
-TEST_CASE("FP Biggy") {
+TEST_CASE("FP Binary File") {
   REQUIRE(rdbase);
   std::string fName(rdbase);
-  std::string libName =
-      fName + "/Code/GraphMol/SynthonSpaceSearch/data/Syntons_5567.csv";
   SynthonSpace synthonspace;
-  synthonspace.readTextFile(libName);
-
+  std::string libName =
+      fName + "/Code/GraphMol/SynthonSpaceSearch/data/idorsia_toy_space_a.spc";
   std::unique_ptr<FingerprintGenerator<std::uint64_t>> fpGen(
-      MorganFingerprint::getMorganGenerator<std::uint64_t>(2));
-
-  std::map<std::string, std::unique_ptr<RWMol>> mols;
-
-  const std::vector<std::string> smis{
-      "c1ccccc1C(=O)N1CCCC1", "c1ccccc1NC(=O)C1CCN1",
-      "c12ccccc1c(N)nc(N)n2", "c12ccc(C)cc1[nH]nc2C(=O)NCc1cncs1",
-      "c1n[nH]cn1",           "C(=O)NC(CC)C(=O)N(CC)C"};
-  const std::vector<size_t> numRes{46, 2, 0, 123, 0, 0};
-  const std::vector<size_t> maxRes{2408, 197, 0, 833, 0, 4};
+      RDKitFP::getRDKitFPGenerator<std::uint64_t>());
+  SearchResults results;
+  auto queryMol = "O=C(Nc1c(CNC=O)cc[s]1)c1nccnc1"_smiles;
   SynthonSpaceSearchParams params;
-  params.approxSimilarityAdjuster = 0.2;
-  params.maxHits = -1;
-  for (size_t i = 0; i < smis.size(); ++i) {
-    auto queryMol = v2::SmilesParse::MolFromSmiles(smis[i]);
-    auto results = synthonspace.fingerprintSearch(*queryMol, *fpGen, params);
-    CHECK(results.getHitMolecules().size() == numRes[i]);
-    CHECK(results.getMaxNumResults() == maxRes[i]);
+  for (auto numThreads : std::vector<int>{1, 2, -1}) {
+    synthonspace.readDBFile(libName, numThreads);
+    params.numThreads = numThreads;
+    CHECK_NOTHROW(
+        results = synthonspace.fingerprintSearch(*queryMol, *fpGen, params));
+    CHECK(results.getHitMolecules().size() == 4);
+    CHECK(results.getMaxNumResults() == 420);
   }
+
+  // Make sure it rejects the wrong sort of fingerprint.
+  synthonspace.readDBFile(libName);
+  fpGen.reset(MorganFingerprint::getMorganGenerator<std::uint64_t>(2));
+  CHECK_THROWS(results = synthonspace.fingerprintSearch(*queryMol, *fpGen));
 }
 
-TEST_CASE("FP Random Hits") {
+TEST_CASE("Missing exact match") {
   REQUIRE(rdbase);
   std::string fName(rdbase);
-  std::string libName =
-      fName + "/Code/GraphMol/SynthonSpaceSearch/data/Syntons_5567.csv";
   SynthonSpace synthonspace;
-  synthonspace.readTextFile(libName);
-
-  auto queryMol = "c12ccc(C)cc1[nH]nc2C(=O)NCc1cncs1"_smiles;
-  SynthonSpaceSearchParams params;
-  params.maxBondSplits = 4;
-  params.maxHits = 100;
-  params.randomSample = true;
-  params.randomSeed = 1;
-  std::unique_ptr<FingerprintGenerator<std::uint64_t>> fpGen(
-      MorganFingerprint::getMorganGenerator<std::uint64_t>(2));
-  auto results = synthonspace.fingerprintSearch(*queryMol, *fpGen, params);
-  std::map<std::string, int> libCounts;
-  for (const auto &m : results.getHitMolecules()) {
-    std::string lib(
-        m->getProp<std::string>(common_properties::_Name).substr(0, 2));
-    if (const auto &c = libCounts.find(lib); c == libCounts.end()) {
-      libCounts.insert(std::make_pair(lib, 1));
-    } else {
-      c->second++;
-    }
-  }
-  CHECK(results.getHitMolecules().size() == 100);
-  std::map<std::string, int> expCounts{{"a1", 100}};
-  CHECK(expCounts == libCounts);
-  CHECK(results.getHitMolecules().front()->getProp<double>("Similarity") ==
-        Catch::Approx(0.711538));
-  CHECK(results.getHitMolecules().back()->getProp<double>("Similarity") ==
-        Catch::Approx(0.5));
-}
-
-TEST_CASE("Other Fingerprints") {
-  REQUIRE(rdbase);
-  std::string fName(rdbase);
   std::string libName =
-      fName + "/Code/GraphMol/SynthonSpaceSearch/data/Syntons_5567.csv";
-  SynthonSpace synthonspace;
-  synthonspace.readTextFile(libName);
-  SynthonSpaceSearchParams params;
-  params.maxBondSplits = 3;
-  params.maxHits = 100;
-  params.randomSample = true;
-  params.randomSeed = 1;
+      fName + "/Code/GraphMol/SynthonSpaceSearch/data/missing_hit.txt";
   std::unique_ptr<FingerprintGenerator<std::uint64_t>> fpGen(
-      MorganFingerprint::getMorganGenerator<std::uint64_t>(3));
-
-  // This is Osimertinib (Tagrisso), which doesn't have any hits in this little
-  // database.
+      RDKitFP::getRDKitFPGenerator<std::uint64_t>());
+  SearchResults results;
   auto queryMol =
-      "C=CC(=O)Nc1cc(Nc2nccc(-c3cn(C)c4ccccc34)n2)c(OC)cc1N(C)CCN(C)C"_smiles;
-  auto results = synthonspace.fingerprintSearch(*queryMol, *fpGen, params);
-  CHECK(results.getHitMolecules().empty());
-}
-
-TEST_CASE("Timeout") {
-  REQUIRE(rdbase);
-  std::string fName(rdbase);
-  std::string libName =
-      fName + "/Code/GraphMol/SynthonSpaceSearch/data/Syntons_5567.csv";
-  SynthonSpace synthonspace;
-  synthonspace.readTextFile(libName);
-  SynthonSpaceSearchParams params;
-  params.maxBondSplits = 3;
-  params.maxHits = -1;
-  params.similarityCutoff = 0.3;
-  params.fragSimilarityAdjuster = 0.3;
-  params.timeOut = 2;
-  std::unique_ptr<FingerprintGenerator<std::uint64_t>> fpGen(
-      MorganFingerprint::getMorganGenerator<std::uint64_t>(3));
-
-  auto queryMol = "c12ccc(C)cc1[nH]nc2C(=O)NCc1cncs1"_smiles;
-  auto results = synthonspace.fingerprintSearch(*queryMol, *fpGen, params);
-  CHECK(results.getTimedOut());
-
-  // Make sure no timeout also works, but only on a short search.
-  params.maxHits = 100;
-  params.similarityCutoff = 0.3;
-  params.fragSimilarityAdjuster = 0.2;
-  params.timeOut = 0;
-  auto results1 = synthonspace.fingerprintSearch(*queryMol, *fpGen, params);
-  CHECK(!results1.getTimedOut());
-}
-
-TEST_CASE("FP Approx Similarity") {
-  REQUIRE(rdbase);
-  std::string fName(rdbase);
-  std::string libName =
-      fName + "/Code/GraphMol/SynthonSpaceSearch/data/Syntons_5567.csv";
-  SynthonSpace synthonspace;
-  synthonspace.readTextFile(libName);
-  SynthonSpaceSearchParams params;
-  // The addFP and subtractFP are built from a random selection of
-  // products so do occasionally vary, so use a fixed seed.
-  params.randomSeed = 1;
-  params.similarityCutoff = 0.5;
-  params.timeOut = 0;
-  params.maxHits = 1000;
-
-  std::unique_ptr<FingerprintGenerator<std::uint64_t>> fpGen(
-      RDKitFP::getRDKitFPGenerator<std::uint64_t>(3));
-  auto queryMol = "c12ccc(C)cc1[nH]nc2C(=O)NCc1cncs1"_smiles;
-
-  // With RDKit fingerprints, 0.05 gives a reasonable compromise
-  // between speed and hits missed.
-  params.approxSimilarityAdjuster = 0.05;
-  auto results = synthonspace.fingerprintSearch(*queryMol, *fpGen, params);
-  CHECK(results.getHitMolecules().size() == 482);
-  CHECK(results.getMaxNumResults() == 1466);
-
-  // A tighter adjuster misses more hits.
-  params.approxSimilarityAdjuster = 0.01;
-  results = synthonspace.fingerprintSearch(*queryMol, *fpGen, params);
-  CHECK(results.getHitMolecules().size() == 124);
-
-  // This is the actual number of hits achievable.
-  params.approxSimilarityAdjuster = 0.25;
-  results = synthonspace.fingerprintSearch(*queryMol, *fpGen, params);
-  CHECK(results.getHitMolecules().size() == 914);
+      "N#Cc1ccc(C(=O)Cn2cc(-c3cn[nH]c3-c3nc4ccccc4[nH]3)nn2)s1"_smiles;
+  bool cancelled = false;
+  synthonspace.readTextFile(libName, cancelled);
+  synthonspace.buildSynthonFingerprints(*fpGen);
+  CHECK_NOTHROW(results = synthonspace.fingerprintSearch(*queryMol, *fpGen));
+  CHECK(results.getHitMolecules().size() == 1);
+  CHECK(results.getHitMolecules()[0]->getProp<double>("Similarity") == 1.0);
 }
