@@ -1,5 +1,5 @@
 //
-//  Copyright (C) 2020 Greg Landrum and T5 Informatics GmbH
+//  Copyright (C) 2020-2022 Greg Landrum and T5 Informatics GmbH
 //
 //   @@ All Rights Reserved @@
 //  This file is part of the RDKit.
@@ -21,15 +21,16 @@ struct chiralityops_wrapper {
   static void wrap() {
     RegisterVectorConverter<Chirality::StereoInfo>();
 
-    python::def("FindPotentialStereo",
-                (std::vector<Chirality::StereoInfo>(*)(ROMol &, bool, bool)) &
-                    Chirality::findPotentialStereo,
-                (python::arg("mol"), python::arg("cleanIt") = false,
-                 python::arg("flagPossible") = true),
-                "find potential stereo elements in a molecule\n\
+    python::def(
+        "FindPotentialStereo",
+        (std::vector<Chirality::StereoInfo>(*)(ROMol &, bool, bool)) &
+            Chirality::findPotentialStereo,
+        (python::arg("mol"), python::arg("cleanIt") = false,
+         python::arg("flagPossible") = true),
+        "find potential stereo elements in a molecule and returns them as StereoInfo objects\n\
 Note that this function is still somewhat experimental and the API\n\
 and results may change in a future release.",
-                python::with_custodian_and_ward_postcall<0, 1>());
+        python::with_custodian_and_ward_postcall<0, 1>());
   };
 };
 }  // namespace RDKit
