@@ -15,6 +15,10 @@
 #include <RDBoost/Wrap.h>
 #include <RDBoost/import_array.h>
 
+#include <RDGeneral/BoostStartInclude.h>
+#include <boost/python/numpy.hpp>
+#include <RDGeneral/BoostEndInclude.h>
+
 #include <sstream>
 #include <utility>
 
@@ -98,6 +102,8 @@ T *next_ptr(O &self) {
 BOOST_PYTHON_MODULE(rdchem) {
   python::scope().attr("__doc__") =
       "Module containing the core chemistry functionality of the RDKit";
+  const bool register_scalar_converters = false;
+  boost::python::numpy::initialize(register_scalar_converters);
   RegisterListConverter<RDKit::Atom *>();
   RegisterListConverter<RDKit::Bond *>();
   RegisterListConverter<RDKit::CONFORMER_SPTR>();
@@ -108,8 +114,8 @@ BOOST_PYTHON_MODULE(rdchem) {
   python::class_<MolSanitizeException>("_cppMolSanitizeException",
                                        "exception arising from sanitization",
                                        python::no_init)
-      .def("Message", &MolSanitizeException::what)
-      .def("GetType", &MolSanitizeException::getType);
+      .def("Message", &MolSanitizeException::what, python::args("self"))
+      .def("GetType", &MolSanitizeException::getType, python::args("self"));
   python::register_ptr_to_python<boost::shared_ptr<MolSanitizeException>>();
   molSanitizeExceptionType = createExceptionClass("MolSanitizeException");
   python::register_exception_translator<RDKit::MolSanitizeException>(
@@ -120,7 +126,8 @@ BOOST_PYTHON_MODULE(rdchem) {
   python::class_<AtomSanitizeException, python::bases<MolSanitizeException>>(
       "_cppAtomSanitizeException", "exception arising from sanitization",
       python::no_init)
-      .def("GetAtomIdx", &AtomSanitizeException::getAtomIdx);
+      .def("GetAtomIdx", &AtomSanitizeException::getAtomIdx,
+           python::args("self"));
   python::register_ptr_to_python<boost::shared_ptr<AtomSanitizeException>>();
   atomSanitizeExceptionType =
       createExceptionClass("AtomSanitizeException", molSanitizeExceptionType);
@@ -174,29 +181,35 @@ BOOST_PYTHON_MODULE(rdchem) {
                                    python::no_init)
       .def("__iter__", &QueryAtomIterSeq::__iter__,
            python::return_internal_reference<
-               1, python::with_custodian_and_ward_postcall<0, 1>>())
+               1, python::with_custodian_and_ward_postcall<0, 1>>(),
+           python::args("self"))
       .def("__next__", &QueryAtomIterSeq::next,
            python::return_internal_reference<
-               1, python::with_custodian_and_ward_postcall<0, 1>>())
-      .def("__len__", &QueryAtomIterSeq::len)
+               1, python::with_custodian_and_ward_postcall<0, 1>>(),
+           python::args("self"))
+      .def("__len__", &QueryAtomIterSeq::len, python::args("self"))
       .def("__getitem__", &QueryAtomIterSeq::get_item,
            python::return_internal_reference<
-               1, python::with_custodian_and_ward_postcall<0, 1>>());
+               1, python::with_custodian_and_ward_postcall<0, 1>>(),
+           python::args("self", "which"));
   python::class_<ConformerIterSeq>(
       "_ROConformerSeq",
       "Read-only sequence of conformers, not constructible from Python.",
       python::no_init)
       .def("__iter__", &ConformerIterSeq::__iter__,
            python::return_internal_reference<
-               1, python::with_custodian_and_ward_postcall<0, 1>>())
+               1, python::with_custodian_and_ward_postcall<0, 1>>(),
+           python::args("self"))
       .def("__next__", next_ptr<ConformerIterSeq, Conformer>,
            python::return_internal_reference<
-               1, python::with_custodian_and_ward_postcall<0, 1>>())
+               1, python::with_custodian_and_ward_postcall<0, 1>>(),
+           python::args("self"))
 
-      .def("__len__", &ConformerIterSeq::len)
+      .def("__len__", &ConformerIterSeq::len, python::args("self"))
       .def("__getitem__", get_item_ptr<ConformerIterSeq, Conformer>,
            python::return_internal_reference<
-               1, python::with_custodian_and_ward_postcall<0, 1>>());
+               1, python::with_custodian_and_ward_postcall<0, 1>>(),
+           python::args("self", "i"));
 
   //*********************************************
   //
