@@ -8,13 +8,13 @@
 #  of the RDKit source tree.
 #
 
-from rdkit import Chem
-from rdkit import Geometry
-from rdkit.Chem import RDConfig
 import os
 import sys
 import unittest
 
+from rdkit import Chem, Geometry
+from rdkit.Chem import RDConfig
+
 
 class TestCase(unittest.TestCase):
 
