@@ -19,6 +19,7 @@
 #include <GraphMol/SmilesParse/SmilesParse.h>
 #include <GraphMol/SmilesParse/SmilesWrite.h>
 #include <GraphMol/SmilesParse/SmartsWrite.h>
+#include <GraphMol/SmilesParse/SmilesJSONParsers.h>
 #include <GraphMol/FileParsers/FileParsers.h>
 #include <GraphMol/MolDraw2D/MolDraw2D.h>
 #include <GraphMol/MolDraw2D/MolDraw2DSVG.h>
@@ -92,9 +93,10 @@ char *str_to_c(const char *str) {
 }
 }  // namespace
 
-void mol_to_pkl(const ROMol &mol, char **mol_pkl, size_t *mol_pkl_sz) {
-  unsigned int propFlags = PicklerOps::PropertyPickleOptions::AllProps ^
-                           PicklerOps::PropertyPickleOptions::ComputedProps;
+void mol_to_pkl(
+    const ROMol &mol, char **mol_pkl, size_t *mol_pkl_sz,
+    unsigned int propFlags = PicklerOps::PropertyPickleOptions::AllProps ^
+                             PicklerOps::PropertyPickleOptions::ComputedProps) {
   std::string pkl;
   MolPickler::pickleMol(mol, pkl, propFlags);
   free(*mol_pkl);
@@ -138,11 +140,11 @@ std::string cxsmiles_helper(const char *pkl, size_t pkl_sz,
   }
   auto params = smiles_helper(details_json);
   auto mol = mol_from_pkl(pkl, pkl_sz);
-  SmilesWrite::CXSmilesFields cxSmilesFields =
-      SmilesWrite::CXSmilesFields::CX_ALL;
-  RestoreBondDirOption restoreBondDirs = RestoreBondDirOptionClear;
+  std::uint32_t cxSmilesFields = SmilesWrite::CXSmilesFields::CX_ALL;
+  unsigned int restoreBondDirs = RestoreBondDirOptionClear;
   updateCXSmilesFieldsFromJSON(cxSmilesFields, restoreBondDirs, details_json);
-  return MolToCXSmiles(mol, params, cxSmilesFields, restoreBondDirs);
+  return MolToCXSmiles(mol, params, cxSmilesFields,
+                       static_cast<RestoreBondDirOption>(restoreBondDirs));
 }
 }  // namespace
 extern "C" char *get_smiles(const char *pkl, size_t pkl_sz,
@@ -276,9 +278,9 @@ extern "C" char *get_mol(const char *input, size_t *pkl_sz,
     *pkl_sz = 0;
     return nullptr;
   }
-  static const unsigned int propFlags =
-      PicklerOps::PropertyPickleOptions::AllProps ^
-      PicklerOps::PropertyPickleOptions::ComputedProps;
+  unsigned int propFlags = PicklerOps::PropertyPickleOptions::AllProps ^
+                           PicklerOps::PropertyPickleOptions::ComputedProps;
+  MinimalLib::updatePropertyPickleOptionsFromJSON(propFlags, details_json);
   std::string pkl;
   MolPickler::pickleMol(*mol, pkl, propFlags);
   return str_to_c(pkl, pkl_sz);
@@ -772,6 +774,21 @@ extern "C" short remove_all_hs(char **mol_pkl, size_t *mol_pkl_sz) {
   return 1;
 }
 
+extern "C" short remove_hs(char **mol_pkl, size_t *mol_pkl_sz,
+                           const char *details_json) {
+  if (!mol_pkl || !mol_pkl_sz || !*mol_pkl || !*mol_pkl_sz) {
+    return 0;
+  }
+  auto mol = mol_from_pkl(*mol_pkl, *mol_pkl_sz);
+  MolOps::RemoveHsParameters ps;
+  bool sanitize = true;
+  MinimalLib::updateRemoveHsParametersFromJSON(ps, sanitize, details_json);
+  MolOps::removeHs(mol, ps, sanitize);
+
+  mol_to_pkl(mol, mol_pkl, mol_pkl_sz);
+  return 1;
+}
+
 // standardization
 namespace {
 template <typename T>
@@ -890,6 +907,77 @@ extern "C" short clear_log_buffer(void *log_handle) {
   return 0;
 }
 
+extern "C" short has_prop(const char *mol_pkl, size_t mol_pkl_sz,
+                          const char *key) {
+  auto mol = mol_from_pkl(mol_pkl, mol_pkl_sz);
+  return mol.hasProp(key);
+}
+
+extern "C" char **get_prop_list(const char *mol_pkl, size_t mol_pkl_sz,
+                                short includePrivate, short includeComputed) {
+  auto mol = mol_from_pkl(mol_pkl, mol_pkl_sz);
+  auto propList = mol.getPropList(includePrivate, includeComputed);
+  std::string propNames;
+  for (const auto &prop : propList) {
+    propNames += prop + ",";
+  }
+  auto resLen = sizeof(char *) * (propList.size() + 1);
+  char **res = (char **)malloc(resLen);
+  if (!res) {
+    return nullptr;
+  }
+  memset(res, 0, resLen);
+  for (size_t i = 0; i < propList.size(); ++i) {
+    res[i] = strdup(propList.at(i).c_str());
+    if (!res[i]) {
+      while (i--) {
+        free(res[i]);
+      }
+      return nullptr;
+    }
+  }
+  return res;
+}
+
+extern "C" void set_prop(char **mol_pkl, size_t *mol_pkl_sz, const char *key,
+                         const char *val, short computed) {
+  auto mol = mol_from_pkl(*mol_pkl, *mol_pkl_sz);
+  std::string valAsString(val);
+  mol.setProp(key, valAsString, computed);
+  mol_to_pkl(mol, mol_pkl, mol_pkl_sz);
+}
+
+extern "C" char *get_prop(const char *mol_pkl, size_t mol_pkl_sz,
+                          const char *key) {
+  auto mol = mol_from_pkl(mol_pkl, mol_pkl_sz);
+  if (!mol.hasProp(key)) {
+    return nullptr;
+  }
+  std::string val;
+  mol.getProp(key, val);
+  return strdup(val.c_str());
+}
+
+extern "C" short clear_prop(char **mol_pkl, size_t *mol_pkl_sz,
+                            const char *key) {
+  auto mol = mol_from_pkl(*mol_pkl, *mol_pkl_sz);
+  short res = mol.hasProp(key);
+  if (res) {
+    mol.clearProp(key);
+    mol_to_pkl(mol, mol_pkl, mol_pkl_sz);
+  }
+  return res;
+}
+
+extern "C" void keep_props(char **mol_pkl, size_t *mol_pkl_sz,
+                           const char *details_json) {
+  auto mol = mol_from_pkl(*mol_pkl, *mol_pkl_sz);
+  unsigned int propFlags = PicklerOps::PropertyPickleOptions::AllProps ^
+                           PicklerOps::PropertyPickleOptions::ComputedProps;
+  MinimalLib::updatePropertyPickleOptionsFromJSON(propFlags, details_json);
+  mol_to_pkl(mol, mol_pkl, mol_pkl_sz, propFlags);
+}
+
 #if (defined(__GNUC__) || defined(__GNUG__))
 #pragma GCC diagnostic pop
 #endif
