@@ -15,6 +15,7 @@ validation values are from the paper (JCICS _35_ 1039-1045 (1995))
 """
 
 import unittest
+
 from rdkit import Chem
 from rdkit.Chem.EState import AtomTypes
 
@@ -47,10 +48,10 @@ class TestCase(unittest.TestCase):
 
   def test2_complexMolecules(self):
     data = [
-      ('c1[nH]cnc1CC(N)C(O)=O', ['aaCH', 'aaNH', 'aaCH', 'aaN', 'aasC', 'ssCH2', 'sssCH', 'sNH2',
-                                 'dssC', 'sOH', 'dO']),
-      ('c1nc[n-]c1CC(N)C(O)=O', ['aaCH', 'aaN', 'aaCH', 'aaN', 'aasC', 'ssCH2', 'sssCH', 'sNH2',
-                                 'dssC', 'sOH', 'dO']),
+      ('c1[nH]cnc1CC(N)C(O)=O',
+       ['aaCH', 'aaNH', 'aaCH', 'aaN', 'aasC', 'ssCH2', 'sssCH', 'sNH2', 'dssC', 'sOH', 'dO']),
+      ('c1nc[n-]c1CC(N)C(O)=O',
+       ['aaCH', 'aaN', 'aaCH', 'aaN', 'aasC', 'ssCH2', 'sssCH', 'sNH2', 'dssC', 'sOH', 'dO']),
       ('c1cccc2c1cccc2',
        ['aaCH', 'aaCH', 'aaCH', 'aaCH', 'aaaC', 'aaaC', 'aaCH', 'aaCH', 'aaCH', 'aaCH']),
     ]
