@@ -79,19 +79,24 @@ class _StereoGroupFlipper(object):
 
 
 def _getFlippers(mol, options):
-  Chem.FindPotentialStereoBonds(mol)
+  sinfo = Chem.FindPotentialStereo(mol)
   flippers = []
   if not options.onlyStereoGroups:
-    for atom in mol.GetAtoms():
-      if atom.HasProp("_ChiralityPossible"):
-        if (not options.onlyUnassigned or atom.GetChiralTag() == Chem.ChiralType.CHI_UNSPECIFIED):
-          flippers.append(_AtomFlipper(atom))
-
-    for bond in mol.GetBonds():
-      bstereo = bond.GetStereo()
-      if bstereo != Chem.BondStereo.STEREONONE:
-        if (not options.onlyUnassigned or bstereo == Chem.BondStereo.STEREOANY):
-          flippers.append(_BondFlipper(bond))
+    for si in sinfo:
+      if options.onlyUnassigned and si.specified not in (Chem.StereoSpecified.Unspecified,
+                                                         Chem.StereoSpecified.Unknown):
+        continue
+      if si.type == Chem.StereoType.Atom_Tetrahedral:
+        flippers.append(_AtomFlipper(mol.GetAtomWithIdx(si.centeredOn)))
+      elif si.type == Chem.StereoType.Bond_Double:
+        bnd = mol.GetBondWithIdx(si.centeredOn)
+        if not bnd.GetStereoAtoms():
+          if si.controllingAtoms[0] == Chem.StereoInfo.NOATOM or \
+            si.controllingAtoms[2] == Chem.StereoInfo.NOATOM:
+            continue
+          bnd.SetStereoAtoms(si.controllingAtoms[0], si.controllingAtoms[2])
+        flippers.append(_BondFlipper(mol.GetBondWithIdx(si.centeredOn)))
+      ## FIX: support atropisomers
 
   if options.onlyUnassigned:
     # otherwise these will be counted twice
@@ -280,7 +285,7 @@ def EnumerateStereoisomers(m, options=StereoEnumerationOptions(), verbose=False)
     F[C@@H](Cl)[C@@H](Cl)[C@@H](Cl)[C@@H](Cl)[C@@H](Cl)[C@@H](Cl)[C@@H](Cl)[C@@H](Cl)[C@@H](Cl)[C@@H](Cl)[C@@H](Cl)[C@@H](Cl)[C@@H](Cl)[C@@H](Cl)[C@@H](Cl)[C@@H](Cl)[C@@H](Cl)[C@H](Cl)[C@@H](Cl)[C@@H](Cl)Br
 
     Or randomly sample a small subset. Note that if we want that sampling to be consistent
-    across python versions we need to provide a random number seed:
+    across runs we need to provide a random number seed:
 
     >>> m = Chem.MolFromSmiles('Br' + '[CH](Cl)' * 20 + 'F')
     >>> opts = StereoEnumerationOptions(maxIsomers=3,rand=0xf00d)
