@@ -4,7 +4,6 @@
 #
 #
 
-
 _version = "0.3.2"
 
 _usage = """
@@ -16,6 +15,7 @@ _usage = """
 _welcomeMessage = "This is ShowFeats version %s" % (_version)
 
 import math
+
 #set up the logger:
 from rdkit import RDLogger as logging
 
@@ -95,10 +95,14 @@ def _cgoArrowhead(viewer, tail, head, radius, color, label, headFrac=0.3, nSteps
 
   normal *= headFrac * aspect
 
-  cgo = [BEGIN, TRIANGLE_FAN, COLOR, color[0], color[1], color[2], NORMAL, dv.x, dv.y, dv.z, VERTEX,
-         head.x + dv.x, head.y + dv.y, head.z + dv.z]
-  base = [BEGIN, TRIANGLE_FAN, COLOR, color[0], color[1], color[2], NORMAL, -dv.x, -dv.y, -dv.z,
-          VERTEX, head.x, head.y, head.z]
+  cgo = [
+    BEGIN, TRIANGLE_FAN, COLOR, color[0], color[1], color[2], NORMAL, dv.x, dv.y, dv.z, VERTEX,
+    head.x + dv.x, head.y + dv.y, head.z + dv.z
+  ]
+  base = [
+    BEGIN, TRIANGLE_FAN, COLOR, color[0], color[1], color[2], NORMAL, -dv.x, -dv.y, -dv.z, VERTEX,
+    head.x, head.y, head.z
+  ]
   v = startP + normal
   cgo.extend([NORMAL, normal.x, normal.y, normal.z])
   cgo.extend([VERTEX, v.x, v.y, v.z])
@@ -127,20 +131,22 @@ def ShowArrow(viewer, tail, head, radius, color, label, transparency=0, includeA
     _globalArrowCGO.extend([ALPHA, 1 - transparency])
   else:
     _globalArrowCGO.extend([ALPHA, 1])
-  _globalArrowCGO.extend([CYLINDER,
-                          tail.x,
-                          tail.y,
-                          tail.z,
-                          head.x,
-                          head.y,
-                          head.z,
-                          radius * .10,
-                          color[0],
-                          color[1],
-                          color[2],
-                          color[0],
-                          color[1],
-                          color[2], ])
+  _globalArrowCGO.extend([
+    CYLINDER,
+    tail.x,
+    tail.y,
+    tail.z,
+    head.x,
+    head.y,
+    head.z,
+    radius * .10,
+    color[0],
+    color[1],
+    color[2],
+    color[0],
+    color[1],
+    color[2],
+  ])
 
   if includeArrowhead:
     _cgoArrowhead(viewer, tail, head, radius, color, label)
@@ -181,27 +187,30 @@ def ShowMolFeats(mol, factory, viewer, radius=0.5, confId=-1, showOnly=True, nam
       _globalSphereCGO.extend([ALPHA, 1 - transparency])
     else:
       _globalSphereCGO.extend([ALPHA, 1])
-    _globalSphereCGO.extend([COLOR, color[0], color[1], color[2], 
-                             SPHERE, pos.x, pos.y, pos.z, radius])
+    _globalSphereCGO.extend(
+      [COLOR, color[0], color[1], color[2], SPHERE, pos.x, pos.y, pos.z, radius])
     if writeFeats:
       aidText = ' '.join([str(x + 1) for x in feat.GetAtomIds()])
       print(f'{family}\t{pos.x:.3f}\t{pos.y:.3f}\t{pos.z:.3f}\t1.0\t# {aidText}')
 
     if featMapFile:
-      print(f"  family={family} pos=({pos.x:.3f}, {pos.y:.3f}, {pos.z:.3f}) weight=1.0", 
-            end='', file=featMapFile)
-      
+      print(f"  family={family} pos=({pos.x:.3f}, {pos.y:.3f}, {pos.z:.3f}) weight=1.0", end='',
+            file=featMapFile)
+
     if useFeatDirs:
       ps = []
       if family == 'Aromatic':
-        ps, _ = FeatDirUtils.GetAromaticFeatVects(mol.GetConformer(confId), feat.GetAtomIds(), pos, scale=1.0)
-      
+        ps, _ = FeatDirUtils.GetAromaticFeatVects(mol.GetConformer(confId), feat.GetAtomIds(), pos,
+                                                  scale=1.0)
+
       elif family == 'Donor':
         aids = feat.GetAtomIds()
         if len(aids) == 1:
-          FeatVectsDictMethod = {1: FeatDirUtils.GetDonor1FeatVects,
-                                 2: FeatDirUtils.GetDonor2FeatVects,
-                                 3: FeatDirUtils.GetDonor3FeatVects, }
+          FeatVectsDictMethod = {
+            1: FeatDirUtils.GetDonor1FeatVects,
+            2: FeatDirUtils.GetDonor2FeatVects,
+            3: FeatDirUtils.GetDonor3FeatVects,
+          }
           featAtom = mol.GetAtomWithIdx(aids[0])
           numHvyNbrs = len([1 for x in featAtom.GetNeighbors() if x.GetAtomicNum() > 1])
           ps, _ = FeatVectsDictMethod[numHvyNbrs](mol.GetConformer(confId), aids, scale=1.0)
@@ -209,9 +218,11 @@ def ShowMolFeats(mol, factory, viewer, radius=0.5, confId=-1, showOnly=True, nam
       elif family == 'Acceptor':
         aids = feat.GetAtomIds()
         if len(aids) == 1:
-          FeatVectsDictMethod = {1: FeatDirUtils.GetDonor1FeatVects,
-                                 2: FeatDirUtils.GetDonor2FeatVects,
-                                 3: FeatDirUtils.GetDonor3FeatVects, }
+          FeatVectsDictMethod = {
+            1: FeatDirUtils.GetDonor1FeatVects,
+            2: FeatDirUtils.GetDonor2FeatVects,
+            3: FeatDirUtils.GetDonor3FeatVects,
+          }
           featAtom = mol.GetAtomWithIdx(aids[0])
           numHvyNbrs = len([x for x in featAtom.GetNeighbors() if x.GetAtomicNum() > 1])
           ps, _ = FeatVectsDictMethod[numHvyNbrs](mol.GetConformer(confId), aids, scale=1.0)
@@ -227,10 +238,14 @@ def ShowMolFeats(mol, factory, viewer, radius=0.5, confId=-1, showOnly=True, nam
       aidText = ' '.join([str(x + 1) for x in feat.GetAtomIds()])
       print(f'# {aidText}', file=featMapFile)
 
+
+import os
 # --- ----  --- ----  --- ----  --- ----  --- ----  --- ----
-import sys, os
-from rdkit import RDConfig
+import sys
 from optparse import OptionParser
+
+from rdkit import RDConfig
+
 parser = OptionParser(_usage, version='%prog ' + _version)
 
 parser.add_option('-x', '--exclude', default='',
@@ -264,7 +279,8 @@ if __name__ == '__main__':
     v = MolViewer()
   except Exception:
     logger.error(
-      'Unable to connect to PyMol server.\nPlease run ~landrgr1/extern/PyMol/launch.sh to start it.')
+      'Unable to connect to PyMol server.\nPlease run ~landrgr1/extern/PyMol/launch.sh to start it.'
+    )
     sys.exit(1)
   if options.clearAll:
     v.DeleteAll()
@@ -337,7 +353,7 @@ if __name__ == '__main__':
       i += 1
       if not i % 100:
         logger.info(f"Done {i} poses")
-    
+
     if ms:
       v.server.renderCGO(_globalSphereCGO, featLabel, 1)
       if options.useDirs:
