@@ -31,12 +31,10 @@
 #  Created by Greg Landrum October 2006
 #
 
-
 import os.path
 import unittest
 
-from rdkit import Chem
-from rdkit import RDConfig
+from rdkit import Chem, RDConfig
 from rdkit.Chem import FunctionalGroups
 
 
