@@ -1,10 +1,10 @@
-
-from rdkit import RDConfig
 import gzip
 import os.path
 import pickle
-from rdkit import Chem
+
+from rdkit import Chem, RDConfig
 from rdkit.Chem import Crippen
+
 Crippen._Init()
 
 
