@@ -1,8 +1,7 @@
+from rdkit import RDConfig
+from rdkit.Dbase import DbUtils
 from io import StringIO
 
-import RDConfig
-from Dbase import DbUtils
-
 basic_2class = """ID,VAL,ACT
 id-1,1.0,0
 id-2,23.0,1
