@@ -1,15 +1,13 @@
-
-
-from rdkit import Chem
-from rdkit import RDConfig
-from rdkit.Dbase import DbModule
-from rdkit.Dbase.DbConnection import DbConnect
 import pickle
 
+from rdkit import Chem, RDConfig
+from rdkit.Dbase import DbModule
+from rdkit.Dbase.DbConnection import DbConnect
+
 if RDConfig.usePgSQL:
-    dbName = "::RDTests"
+  dbName = "::RDTests"
 else:
-    dbName = "data.sqlt"
+  dbName = "data.sqlt"
 
 molTblName = 'simple_mols1'
 fpTblName = 'simple_mols1_fp'
@@ -17,9 +15,9 @@ conn = DbConnect(dbName, molTblName)
 conn.AddTable(fpTblName, 'id varchar(10),autofragmentfp %s' % DbModule.binaryTypeName)
 d = conn.GetData()
 for smi, ID in d:
-    print(repr(ID), repr(smi))
-    mol = Chem.MolFromSmiles(smi)
-    fp = Chem.RDKFingerprint(mol)
-    pkl = pickle.dumps(fp)
-    conn.InsertData(fpTblName, (ID, DbModule.binaryHolder(pkl)))
+  print(repr(ID), repr(smi))
+  mol = Chem.MolFromSmiles(smi)
+  fp = Chem.RDKFingerprint(mol)
+  pkl = pickle.dumps(fp)
+  conn.InsertData(fpTblName, (ID, DbModule.binaryHolder(pkl)))
 conn.Commit()
